@@ -11,8 +11,11 @@
 #include <ws2tcpip.h>
 
 extern "C" {
+#include <afsconfig.h>
 #include <afs/param.h>
 #include <afs/stds.h>
+
+#include <roken.h>
 }
 
 #include <WINNT/afsapplib.h>
