@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -96,9 +96,9 @@ static size_t           cDate = 0;
 
 #define cszDATECLASS TEXT("Date")
 
-BOOL CALLBACK DateProc (HWND hDate, UINT msg, WPARAM wp, LPARAM lp);
-BOOL CALLBACK DateEditProc (HWND hEdit, UINT msg, WPARAM wp, LPARAM lp);
-BOOL CALLBACK DateDlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp);
+HRESULT CALLBACK DateProc (HWND hDate, UINT msg, WPARAM wp, LPARAM lp);
+HRESULT CALLBACK DateEditProc (HWND hEdit, UINT msg, WPARAM wp, LPARAM lp);
+HRESULT CALLBACK DateDlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp);
 
 void Date_SendCallback (DateInfo *pdi, WORD eln, LPARAM lp);
 
@@ -154,7 +154,7 @@ void Date_SendCallback (DateInfo *pdi, WORD eln, LPARAM lp)
 }
 
 
-BOOL CALLBACK DateProc (HWND hDate, UINT msg, WPARAM wp, LPARAM lp)
+HRESULT CALLBACK DateProc (HWND hDate, UINT msg, WPARAM wp, LPARAM lp)
 {
    DateInfo *pdi = NULL;
 
@@ -333,7 +333,7 @@ void Date_OnCreate (DateInfo *pdi)
                 WS_CHILD | WS_TABSTOP | ES_RIGHT | ES_NUMBER | ES_MULTILINE,
                 xx, yy, cx, cy,
                 GetParent(pdi->hDate),
-                (HMENU)id,
+                (HMENU)(INT_PTR)id,
                 THIS_HINST,
                 0);
    xx += cx;
@@ -374,7 +374,7 @@ void Date_OnCreate (DateInfo *pdi)
                 WS_CHILD | WS_TABSTOP | ES_RIGHT | ES_NUMBER | ES_MULTILINE,
                 xx, yy, cx, cy,
                 GetParent(pdi->hDate),
-                (HMENU)id,
+                (HMENU)(INT_PTR)id,
                 THIS_HINST,
                 0);
    xx += cx;
@@ -414,9 +414,9 @@ void Date_OnCreate (DateInfo *pdi)
                 WS_CHILD | WS_TABSTOP | ES_RIGHT | ES_NUMBER | ES_MULTILINE,
                 xx, yy, cx, cy,
                 GetParent(pdi->hDate),
-                (HMENU)id,
+                (HMENU)(INT_PTR)id,
                 THIS_HINST,
-                0);
+				0);
    xx += cx;
 
    switch (pdi->dwFormat)
@@ -532,7 +532,7 @@ BOOL Date_OnSetDate (DateInfo *pdi, WPARAM wp, LPARAM lp)
 }
 
 
-BOOL CALLBACK DateDlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
+HRESULT CALLBACK DateDlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
 {
    PVOID oldProc = Subclass_FindNextHook (hDlg, DateDlgProc);
    size_t iDate;
@@ -557,7 +557,7 @@ BOOL CALLBACK DateDlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
                else
                   clr = GetSysColor (COLOR_BTNFACE);
                SetBkColor ((HDC)wp, clr);
-               return (BOOL)CreateSolidBrush (clr);
+               return (BOOL)(INT_PTR)CreateSolidBrush (clr);
                }
             }
          break;
@@ -588,7 +588,7 @@ BOOL CALLBACK DateDlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
 }
 
 
-BOOL CALLBACK DateEditProc (HWND hEdit, UINT msg, WPARAM wp, LPARAM lp)
+HRESULT CALLBACK DateEditProc (HWND hEdit, UINT msg, WPARAM wp, LPARAM lp)
 {
    DateInfo *pdi = NULL;
 
