@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -636,18 +636,6 @@ LONG APIENTRY SplitterWndProc (HWND hWnd, UINT msg, WPARAM wp, LPARAM lp)
                   SetWindowLong (hWnd, GWL_USER, 0);
                   }
                break;
-
-#if 0 // Enable me to make the splitters draw in black
-         case WM_PAINT:
-               {
-               PAINTSTRUCT ps;
-               HDC hdc = BeginPaint (hWnd, &ps);
-               FillRect (hdc, &ps.rcPaint, GetStockObject(BLACK_BRUSH));
-               EndPaint (hWnd, &ps);
-               return 0;
-               }
-               break;
-#endif
          }
       }
 
