@@ -72,32 +72,16 @@
 #include <string.h>
 #include <time.h>
 #include <winsock2.h>
-
-#ifdef USE_MS2MIT
-#include <loadfuncs-lsa.h>
-#endif /* USE_MS2MIT */
+#include <process.h>
 
 #include <afs/stds.h>
 #include <krb5.h>
 
 #include <rxkad.h>
 
-/* Defined in the KRBV4W32 version of krb.h but not the Kerberos V version */
-/* Required for some of the loadfuncs headers */
-typedef struct ktext far *KTEXT;
-typedef struct ktext far *KTEXT_FP;
-#include <KerberosIV/krb.h>
-
 /* AFS has its own version of com_err.h */
 typedef afs_int32 errcode_t;
 
-#include <loadfuncs-com_err.h>
-#include <loadfuncs-krb5.h>
-#include <loadfuncs-profile.h>
-#include <loadfuncs-krb.h>
-#include <loadfuncs-krb524.h>
-#include <loadfuncs-leash.h>
-
 // service definitions
 #define SERVICE_DLL   "advapi32.dll"
 typedef SC_HANDLE (WINAPI *FP_OpenSCManagerA)(char *, char *, DWORD);
@@ -106,7 +90,12 @@ typedef BOOL (WINAPI *FP_QueryServiceStatus)(SC_HANDLE, LPSERVICE_STATUS);
 typedef BOOL (WINAPI *FP_CloseServiceHandle)(SC_HANDLE);
 
 #define KRB5_DEFAULT_LIFE            60*60*10 /* 10 hours */
-#define LSA_CCNAME                   "MSLSA:"
+#define LSA_CCTYPE                   "MSLSA"
+#define LSA_CCNAME                   LSA_CCTYPE ":"
+
+#ifndef REALM_SZ
+#define REALM_SZ     64
+#endif
 
 #ifndef KTC_ERROR
 #define KTC_ERROR      11862784L
@@ -149,115 +138,38 @@ struct cell_principal_map {
     int    active;
 };
 
-/* In order to avoid including the private CCAPI headers */
-typedef int cc_int32;
-
-#define CC_API_VER_1 1
-#define CC_API_VER_2 2
-
-#define CCACHE_API cc_int32
-
-/*
-** The Official Error Codes
-*/
-#define CC_NOERROR           0
-#define CC_BADNAME           1
-#define CC_NOTFOUND          2
-#define CC_END               3
-#define CC_IO                4
-#define CC_WRITE             5
-#define CC_NOMEM             6
-#define CC_FORMAT            7
-#define CC_LOCKED            8
-#define CC_BAD_API_VERSION   9
-#define CC_NO_EXIST          10
-#define CC_NOT_SUPP          11
-#define CC_BAD_PARM          12
-#define CC_ERR_CACHE_ATTACH  13
-#define CC_ERR_CACHE_RELEASE 14
-#define CC_ERR_CACHE_FULL    15
-#define CC_ERR_CRED_VERSION  16
-
-enum {
-    CC_CRED_VUNKNOWN = 0,       // For validation
-    CC_CRED_V4 = 1,
-    CC_CRED_V5 = 2,
-    CC_CRED_VMAX = 3            // For validation
-};
-
-typedef struct opaque_dll_control_block_type* apiCB;
-typedef struct _infoNC {
-    char*     name;
-    char*     principal;
-    cc_int32  vers;
-} infoNC;
-
-TYPEDEF_FUNC(
-CCACHE_API,
-CALLCONV_C,
-cc_initialize,
-    (
-    apiCB** cc_ctx,           // <  DLL's primary control structure.
-                              //    returned here, passed everywhere else
-    cc_int32 api_version,     // >  ver supported by caller (use CC_API_VER_1)
-    cc_int32*  api_supported, // <  if ~NULL, max ver supported by DLL
-    const char** vendor       // <  if ~NULL, vendor name in read only C string
-    )
-);
-
-TYPEDEF_FUNC(
-CCACHE_API,
-CALLCONV_C,
-cc_shutdown,
-    (
-    apiCB** cc_ctx            // <> DLL's primary control structure. NULL after
-    )
-);
-
-TYPEDEF_FUNC(
-CCACHE_API,
-CALLCONV_C,
-cc_get_NC_info,
-    (
-    apiCB* cc_ctx,          // >  DLL's primary control structure
-    struct _infoNC*** ppNCi // <  (NULL before call) null terminated,
-                            //    list of a structs (free via cc_free_infoNC())
-    )
-);
-
-TYPEDEF_FUNC(
-CCACHE_API,
-CALLCONV_C,
-cc_free_NC_info,
-    (
-    apiCB* cc_ctx,
-    struct _infoNC*** ppNCi // <  free list of structs returned by
-                            //    cc_get_cache_names().  set to NULL on return
-    )
-);
-
-#ifdef _WIN64
-#define CCAPI_DLL   "krbcc64.dll"
-#else
-#define CCAPI_DLL   "krbcc32.dll"
-#endif
-
 /* Function Prototypes */
 DWORD GetServiceStatus(LPSTR, LPSTR, DWORD *);
+
 void KFW_AFS_error(LONG, LPCSTR);
 
-void UnloadFuncs(FUNC_INFO [], HINSTANCE);
-int  LoadFuncs(const char*, FUNC_INFO [], HINSTANCE*, int*, int, int, int);
 int  KFW_get_ccache(krb5_context, krb5_principal, krb5_ccache *);
+
 int  KFW_error(krb5_error_code, LPCSTR, int, krb5_context *, krb5_ccache *);
+
 int  KFW_kinit(krb5_context, krb5_ccache, HWND, char *, char *, krb5_deltat,
-                DWORD, DWORD, krb5_deltat, DWORD, DWORD);
+               DWORD, DWORD, krb5_deltat, DWORD, DWORD);
+
 int  KFW_renew(krb5_context, krb5_ccache);
+
 int  KFW_destroy(krb5_context, krb5_ccache);
+
 BOOL KFW_ms2mit(krb5_context, krb5_ccache, BOOL);
+
 int  KFW_AFS_unlog(void);
+
 int  KFW_AFS_klog(krb5_context, krb5_ccache, char*, char*, char*, int, char*);
+
 void KFW_import_ccache_data(void);
+
 BOOL MSLSA_IsKerberosLogon();
+
 char *afs_realm_of_cell(krb5_context, struct afsconf_cell *);
+
+DWORD KFW_get_default_mslsa_import(krb5_context);
+
+DWORD KFW_get_default_lifetime(krb5_context, const char *);
+
+void KFW_enable_DES(krb5_context);
+
 #endif /* AFSKFW_INT_H */
