@@ -1997,6 +1997,57 @@ int  cm_BPlusDirDeleteEntry(cm_dirOp_t * op, clientchar_t *centry)
 
 }
 
+/*
+   On entry:
+       op->scp->dirlock is read locked
+
+   On exit:
+       op->scp->dirlock is read locked
+
+   Return:
+
+*/
+int cm_BPlusDirIsEmpty(cm_dirOp_t *op, afs_uint32 *pbEmpty)
+{
+    int rc = 0;
+    afs_uint32 count = 0, slot, numentries;
+    Nptr leafNode = NONODE, nextLeafNode;
+    Nptr firstDataNode, dataNode, nextDataNode;
+
+    if (op->scp->dirBplus == NULL ||
+        op->dataVersion != op->scp->dirDataVersion) {
+        rc = EINVAL;
+        goto done;
+    }
+
+    /* If we find any entry that is not "." or "..", the directory is not empty */
+
+    for (count = 0, leafNode = getleaf(op->scp->dirBplus); leafNode; leafNode = nextLeafNode) {
+
+	for ( slot = 1, numentries = numentries(leafNode); slot <= numentries; slot++) {
+	    firstDataNode = getnode(leafNode, slot);
+
+	    for ( dataNode = firstDataNode; dataNode; dataNode = nextDataNode) {
+
+                if ( cm_ClientStrCmp(getdatavalue(dataNode).cname, L".") &&
+                     cm_ClientStrCmp(getdatavalue(dataNode).cname, L".."))
+                {
+
+                    *pbEmpty = 0;
+                    goto done;
+                }
+
+		nextDataNode = getdatanext(dataNode);
+	    }
+	}
+	nextLeafNode = getnextnode(leafNode);
+    }
+
+    *pbEmpty = 1;
+
+  done:
+    return rc;
+}
 
 int cm_BPlusDirFoo(struct cm_scache *scp, struct cm_dirEntry *dep,
                    void *dummy, osi_hyper_t *entryOffsetp)
@@ -2096,9 +2147,6 @@ long cm_BPlusDirBuildTree(cm_scache_t *scp, cm_user_t *userp, cm_req_t* reqp)
 
     bplus_build_time += (end.QuadPart - start.QuadPart);
 
-#if 0
-    cm_BPlusDirEnumTest(scp, 1);
-#endif
     return rc;
 }
 
@@ -2357,6 +2405,7 @@ cm_BPlusDirEnumBulkStat(cm_direnum_t *enump)
     int i;
     cm_scache_t   *tscp;
     afs_int32 nobulkstat = 0;
+    afs_int32 base = 1;
 
     cm_InitReq(&req);
     req.flags = enump->reqFlags;
@@ -2443,6 +2492,7 @@ cm_BPlusDirEnumBulkStat(cm_direnum_t *enump)
         enump->entry[count].flags |= CM_DIRENUM_FLAG_GOT_STATUS;
 
         if (bsp->counter == AFSCBMAX) {
+            base = 0;
             code = cm_TryBulkStatRPC(dscp, bsp, userp, &req);
             if (code == CM_ERROR_BULKSTAT_FAILURE) {
                 /*
@@ -2487,7 +2537,12 @@ cm_BPlusDirEnumBulkStat(cm_direnum_t *enump)
         }
     }
 
-    if (bsp->counter > 0) {
+    /*
+     * if the counter is 1, only the directory entry is in the list,
+     * do not issue the RPC.
+     */
+
+    if (bsp->counter > base) {
         code = cm_TryBulkStatRPC(dscp, bsp, userp, &req);
         if (code == CM_ERROR_BULKSTAT_FAILURE) {
             /*
@@ -2652,8 +2707,14 @@ cm_BPlusDirEnumBulkStatOne(cm_direnum_t *enump, cm_scache_t *scp)
         bsp->counter++;
     }
 
-    if (bsp->counter > 0) {
+    /*
+     * if the counter is 1, only the directory entry is in the list,
+     * do not issue the RPC.
+     */
+
+    if (bsp->counter > 1) {
         code = cm_TryBulkStatRPC(dscp, bsp, userp, &req);
+
         /* Now process any errors that might have occurred */
         if (code == CM_ERROR_BULKSTAT_FAILURE) {
             for (i=2; i<bsp->counter; i++) {
@@ -2786,8 +2847,14 @@ cm_BPlusDirEnumBulkStatNext(cm_direnum_t *enump)
         bsp->counter++;
     }
 
-    if (bsp->counter > 0) {
+    /*
+     * if the counter is 1, only the directory entry is in the list,
+     * do not issue the RPC.
+     */
+
+    if (bsp->counter > 1) {
         code = cm_TryBulkStatRPC(dscp, bsp, userp, &req);
+
         /* Now process any errors that might have occurred */
         if (code == CM_ERROR_BULKSTAT_FAILURE) {
             for (i=0; i<bsp->counter; i++) {
