@@ -1,16 +1,16 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef __CM_DIR_ENV__
-#define __CM_DIR_ENV__ 1
+#ifndef OPENAFS_WINNT_AFSD_CM_DIR_H
+#define OPENAFS_WINNT_AFSD_CM_DIR_H 1
 
-/* These data structures are derived from src/dir/dir.h and should not 
+/* These data structures are derived from src/dir/dir.h and should not
  * be changed as they describe AFS3 wire protocol.
  *
  */
@@ -101,10 +101,15 @@ typedef struct cm_dirOpBuffer {
 
 #define CM_DIROPBUFF_INUSE      0x1
 
+/* lock types */
 #define CM_DIRLOCK_NONE         0x0
 #define CM_DIRLOCK_READ         0x1
 #define CM_DIRLOCK_WRITE        0x2
 
+/* flags for cm_dirOp operations */
+#define CM_DIROP_FLAG_NONE         0x0000
+#define CM_DIROP_FLAG_NOBUILDTREE  0x0001
+
 /* Used for managing transactional directory operations.  Each
    instance should only be used by one thread. */
 typedef struct cm_dirOp {
@@ -130,7 +135,7 @@ typedef struct cm_dirOp {
 
 extern long
 cm_BeginDirOp(cm_scache_t * scp, cm_user_t * userp, cm_req_t * reqp,
-              afs_uint32 lockType, cm_dirOp_t * op);
+              afs_uint32 lockType, afs_uint32 flags, cm_dirOp_t * op);
 
 extern int
 cm_CheckDirOpForSingleChange(cm_dirOp_t * op);
@@ -139,7 +144,7 @@ extern long
 cm_EndDirOp(cm_dirOp_t * op);
 
 extern long
-cm_NameEntries(char *namep, long *lenp);
+cm_NameEntries(char *namep, size_t *lenp);
 
 extern long
 cm_DirCreateEntry(cm_dirOp_t * op, char *entry, cm_fid_t * cfid);
@@ -187,4 +192,5 @@ extern int
 cm_MemDumpDirStats(FILE *outputFile, char *cookie, int lock);
 
 extern afs_uint64 dir_enums;
-#endif /*  __CM_DIR_ENV__ */
+
+#endif /*  OPENAFS_WINNT_AFSD_CM_DIR_H */
