@@ -165,7 +165,7 @@ long AFSRPC_GetToken(
 
 void __RPC_FAR * __RPC_USER midl_user_allocate (size_t cBytes)
 {
-    return ((void __RPC_FAR *) malloc(cBytes));
+    return ((void __RPC_FAR *) calloc(cBytes, 1));
 }
 
 void __RPC_USER midl_user_free(void __RPC_FAR * p)
