@@ -561,19 +561,19 @@ extern void CompensateForSmbClientLastWriteTimeBugs(afs_uint32 *dosTimep);
 
 #ifdef DEBUG_SMB_REFCOUNT
 extern smb_vc_t *smb_FindVCDbg(unsigned short lsn, int flags, int lana, char *, long);
-#define smb_FindVC(a,b,c) smb_FindVCDbg(a,b,c,__FILE__,__LINE__);
+#define smb_FindVC(a,b,c) smb_FindVCDbg(a,b,c,__FILE__,__LINE__)
 
 extern void smb_HoldVCDbg(smb_vc_t *vcp, char *, long);
-#define smb_HoldVC(a) smb_HoldVCDbg(a,__FILE__,__LINE__);
+#define smb_HoldVC(a) smb_HoldVCDbg(a,__FILE__,__LINE__)
 
 extern void smb_HoldVCNoLockDbg(smb_vc_t *vcp, char *, long);
-#define smb_HoldVCNoLock(a) smb_HoldVCNoLockDbg(a,__FILE__,__LINE__);
+#define smb_HoldVCNoLock(a) smb_HoldVCNoLockDbg(a,__FILE__,__LINE__)
 
 extern void smb_ReleaseVCDbg(smb_vc_t *vcp, char *, long);
-#define smb_ReleaseVC(a) smb_ReleaseVCDbg(a,__FILE__,__LINE__);
+#define smb_ReleaseVC(a) smb_ReleaseVCDbg(a,__FILE__,__LINE__)
 
 extern void smb_ReleaseVCNoLockDbg(smb_vc_t *vcp, char *, long);
-#define smb_ReleaseVCNoLock(a) smb_ReleaseVCNoLockDbg(a,__FILE__,__LINE__);
+#define smb_ReleaseVCNoLock(a) smb_ReleaseVCNoLockDbg(a,__FILE__,__LINE__)
 #else
 extern smb_vc_t *smb_FindVC(unsigned short lsn, int flags, int lana);
 
@@ -592,13 +592,13 @@ extern void smb_MarkAllVCsDead(smb_vc_t *exclude_vcp);
 
 #ifdef DEBUG_SMB_REFCOUNT
 extern smb_tid_t *smb_FindTIDDbg(smb_vc_t *vcp, unsigned short tid, int flags, char *, long);
-#define smb_FindTID(a,b,c) smb_FindTIDDbg(a,b,c,__FILE__,__LINE__);
+#define smb_FindTID(a,b,c) smb_FindTIDDbg(a,b,c,__FILE__,__LINE__)
 
 extern void smb_HoldTIDNoLockDbg(smb_tid_t *tidp, char *, long);
-#define smb_HoldTIDNoLock(a) smb_HoldTIDNoLockDbg(a,__FILE__,__LINE__);
+#define smb_HoldTIDNoLock(a) smb_HoldTIDNoLockDbg(a,__FILE__,__LINE__)
 
 extern void smb_ReleaseTIDDbg(smb_tid_t *tidp, afs_uint32 locked, char *, long);
-#define smb_ReleaseTID(a,b) smb_ReleaseTIDDbg(a,b,__FILE__,__LINE__);
+#define smb_ReleaseTID(a,b) smb_ReleaseTIDDbg(a,b,__FILE__,__LINE__)
 #else
 extern smb_tid_t *smb_FindTID(smb_vc_t *vcp, unsigned short tid, int flags);
 
@@ -633,16 +633,16 @@ extern long smb_LookupTIDPath(smb_vc_t *vcp, unsigned short tid, clientchar_t **
 
 #ifdef DEBUG_SMB_REFCOUNT
 extern smb_fid_t *smb_FindFIDDbg(smb_vc_t *vcp, unsigned short fid, int flags, char *, long);
-#define smb_FindFID(a,b,c) smb_FindFIDDbg(a,b,c,__FILE__,__LINE__);
+#define smb_FindFID(a,b,c) smb_FindFIDDbg(a,b,c,__FILE__,__LINE__)
 
 extern smb_fid_t *smb_FindFIDByScacheDbg(smb_vc_t *vcp, cm_scache_t * scp, char *, long);
-#define smb_FindFIDByScache(a,b) smb_FindFIDByScacheDbg(a,b,__FILE__,__LINE__);
+#define smb_FindFIDByScache(a,b) smb_FindFIDByScacheDbg(a,b,__FILE__,__LINE__)
 
 extern void smb_HoldFIDNoLockDbg(smb_fid_t *fidp, char *, long);
-#define smb_HoldFIDNoLock(a) smb_HoldFIDNoLockDbg(a,__FILE__,__LINE__);
+#define smb_HoldFIDNoLock(a) smb_HoldFIDNoLockDbg(a,__FILE__,__LINE__)
 
 extern void smb_ReleaseFIDDbg(smb_fid_t *fidp, char *, long);
-#define smb_ReleaseFID(a) smb_ReleaseFIDDbg(a,__FILE__,__LINE__);
+#define smb_ReleaseFID(a) smb_ReleaseFIDDbg(a,__FILE__,__LINE__)
 #else
 extern smb_fid_t *smb_FindFID(smb_vc_t *vcp, unsigned short fid, int flags);
 
