@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2008-2011 Kernel Drivers, LLC.
- * Copyright (c) 2009-2011 Your File System, Inc.
- * All rights reserved.
+* Copyright (c) 2008, 2009, 2010, 2011, 2012, 2013 Kernel Drivers, LLC.
+* Copyright (c) 2009, 2010, 2011, 2012, 2013 Your File System, Inc.
+* All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -10,15 +10,12 @@
  * - Redistributions of source code must retain the above copyright notice,
  *   this list of conditions and the following disclaimer.
  * - Redistributions in binary form must reproduce the above copyright
- *   notice,
- *   this list of conditions and the following disclaimer in the
- *   documentation
- *   and/or other materials provided with the distribution.
+ *   notice, this list of conditions and the following disclaimer in the
+ *   documentation and/or other materials provided with the distribution.
  * - Neither the name of Kernel Drivers, LLC nor the names of its
- *   contributors may be
- *   used to endorse or promote products derived from this software without
- *   specific prior written permission from Kernel Drivers, LLC
- *   and Your File System, Inc.
+ *   contributors may be used to endorse or promote products derived from
+ *   this software without specific prior written permission from
+ *   Kernel Drivers, LLC and Your File System, Inc.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -134,6 +131,8 @@ typedef struct _AFS_REDIR_INIT_INFO_CB
                                         // dynamic and will be increased in size as
                                         // needed by this amount
 
+    ULONG       GlobalReparsePointPolicy; // One or more of AFS_REPARSE_POINT_VALID_POLICY_FLAGS
+
     LARGE_INTEGER MemoryCacheOffset;    // The offset in the afsd_service process memory
                                         // space at which the extents are allocated
     LARGE_INTEGER MemoryCacheLength;    // and the length of the allocated region
@@ -1311,5 +1310,22 @@ typedef struct _AFS_FILE_IO_RESULT_CB
 
 } AFSFileIOResultCB;
 
-#endif /* _AFS_USER_STRUCT_H */
+typedef struct _AFS_SET_REPARSE_POINT_POLICY
+{
 
+    ULONG       Policy;
+
+    ULONG       Scope;
+
+} AFSSetReparsePointPolicyCB;
+
+typedef struct _AFS_GET_REPARSE_POINT_POLICY
+{
+
+    ULONG       GlobalPolicy;
+
+    ULONG       ActivePolicy;
+
+} AFSGetReparsePointPolicyCB;
+
+#endif /* _AFS_USER_STRUCT_H */
