@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2008, 2009, 2010, 2011 Kernel Drivers, LLC.
- * Copyright (c) 2009, 2010, 2011 Your File System, Inc.
+ * Copyright (c) 2009, 2010, 2011, 2015 Your File System, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ AFSAddConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
 
     NTSTATUS ntStatus = STATUS_SUCCESS;
     AFSProviderConnectionCB *pConnection = NULL, *pLastConnection = NULL;
-    UNICODE_STRING uniRemoteName;
+    UNICODE_STRING uniRemoteName, uniServerName, uniShareName, uniRemainingPath;
     AFSDeviceExt *pRDRDevExt = (AFSDeviceExt *)AFSRDRDeviceObject->DeviceExtension;
 
     __Enter
@@ -58,16 +58,31 @@ AFSAddConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
                       &pRDRDevExt->Specific.RDR.ProviderListLock,
                       PsGetCurrentThread()));
 
-        if( ConnectCB->AuthenticationId.QuadPart == 0)
-        {
+	ntStatus = AFSGetAuthenticationId(&ConnectCB->AuthenticationId);
 
-            ConnectCB->AuthenticationId = AFSGetAuthenticationId();
+	if ( !NT_SUCCESS( ntStatus))
+	{
 
-            AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                          AFS_TRACE_LEVEL_VERBOSE,
-                          "AFSAddConnection Retrieved authentication id %I64X\n",
-                          ConnectCB->AuthenticationId.QuadPart));
-        }
+	    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			  AFS_TRACE_LEVEL_ERROR,
+			  "AFSAddConnection Unable to retrieve authentication id %08lX\n",
+			  ntStatus));
+
+	    return ntStatus;
+	}
+
+	AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+		      AFS_TRACE_LEVEL_VERBOSE,
+		      "AFSAddConnection Retrieved authentication id %I64X\n",
+		      ConnectCB->AuthenticationId.QuadPart));
+
+	uniServerName.Length = 0;
+	uniServerName.MaximumLength = 0;
+	uniServerName.Buffer = NULL;
+
+	uniShareName.Length = 0;
+	uniShareName.MaximumLength = 0;
+	uniShareName.Buffer = NULL;
 
         AFSAcquireExcl( &pRDRDevExt->Specific.RDR.ProviderListLock,
                         TRUE);
@@ -82,11 +97,12 @@ AFSAddConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
         uniRemoteName.Buffer = ConnectCB->RemoteName;
 
         //
-        // Strip off any trailing slashes
-        //
+	// Strip off any trailing slashes
+	//
 
-        if( uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
-        {
+	if( uniRemoteName.Length >= sizeof( WCHAR)
+	    && uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
+	{
 
             uniRemoteName.Length -= sizeof( WCHAR);
         }
@@ -96,6 +112,28 @@ AFSAddConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
         while( pConnection != NULL)
         {
 
+	    if( pConnection->LocalName != L'\0')
+	    {
+
+		AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			      AFS_TRACE_LEVEL_VERBOSE,
+			      "AFSAddConnection Comparing passed in %C to %C authentication id %I64X - %I64X\n",
+			      ConnectCB->LocalName,
+			      pConnection->LocalName,
+			      ConnectCB->AuthenticationId.QuadPart,
+			      pConnection->AuthenticationId.QuadPart));
+	    }
+	    else
+	    {
+
+		AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			      AFS_TRACE_LEVEL_VERBOSE,
+			      "AFSAddConnection Comparing passed in %C to (NULL) authentication id %I64X - %I64X\n",
+			      ConnectCB->LocalName,
+			      ConnectCB->AuthenticationId.QuadPart,
+			      pConnection->AuthenticationId.QuadPart));
+	    }
+
             if( pConnection->LocalName == ConnectCB->LocalName &&
                 pConnection->AuthenticationId.QuadPart == ConnectCB->AuthenticationId.QuadPart &&
                 RtlCompareUnicodeString( &uniRemoteName,
@@ -155,106 +193,82 @@ AFSAddConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
             uniRemoteName.Length -= (2 * sizeof( WCHAR));
         }
 
-        if( uniRemoteName.Length >= AFSServerName.Length)
-        {
+	FsRtlDissectName( uniRemoteName,
+			  &uniServerName,
+			  &uniRemainingPath);
 
-            USHORT usLength = uniRemoteName.Length;
+	if( RtlCompareUnicodeString( &uniServerName,
+				     &AFSServerName,
+				     TRUE) != 0)
+	{
 
-            if (uniRemoteName.Buffer[AFSServerName.Length/sizeof( WCHAR)] != L'\\')
-            {
+	    if( ConnectCB->LocalName != L'\0')
+	    {
 
-                if( ConnectCB->LocalName != L'\0')
-                {
+		AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			      AFS_TRACE_LEVEL_VERBOSE,
+			      "AFSAddConnection Bad Server Name remote name %wZ Local %C authentication id %I64X\n",
+			      &uniRemoteName,
+			      ConnectCB->LocalName,
+			      ConnectCB->AuthenticationId.QuadPart));
+	    }
+	    else
+	    {
 
-                    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                                  AFS_TRACE_LEVEL_VERBOSE,
-                                  "AFSAddConnection BAD_NETNAME 1 remote name %wZ Local %C authentication id %I64X\n",
-                                  &uniRemoteName,
-                                  ConnectCB->LocalName,
-                                  ConnectCB->AuthenticationId.QuadPart));
-                }
-                else
-                {
+		AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			      AFS_TRACE_LEVEL_VERBOSE,
+			      "AFSAddConnection Bad Server Name remote name %wZ Local (NULL) authentication id %I64X\n",
+			      &uniRemoteName,
+			      ConnectCB->AuthenticationId.QuadPart));
+	    }
 
-                    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                                  AFS_TRACE_LEVEL_VERBOSE,
-                                  "AFSAddConnection BAD_NETNAME 1 remote name %wZ Local (NULL) authentication id %I64X\n",
-                                  &uniRemoteName,
-                                  ConnectCB->AuthenticationId.QuadPart));
-                }
+	    *ResultStatus = WN_BAD_NETNAME;
 
-                *ResultStatus = WN_BAD_NETNAME;
+	    *ReturnOutputBufferLength = sizeof( ULONG);
 
-                *ReturnOutputBufferLength = sizeof( ULONG);
+	    try_return( ntStatus = STATUS_SUCCESS);
+	}
 
-                try_return( ntStatus = STATUS_SUCCESS);
-            }
+	if (uniRemainingPath.Length > 0)
+	{
 
-            uniRemoteName.Length = AFSServerName.Length;
+	    AFSProviderConnectionCB *pConnection;
 
-            if( RtlCompareUnicodeString( &AFSServerName,
-                                         &uniRemoteName,
-                                         TRUE) != 0)
-            {
+	    FsRtlDissectName( uniRemainingPath,
+			      &uniShareName,
+			      &uniRemainingPath);
 
-                if( ConnectCB->LocalName != L'\0')
-                {
+	    pConnection = AFSLocateEnumRootEntry( &uniShareName);
 
-                    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                                  AFS_TRACE_LEVEL_VERBOSE,
-                                  "AFSAddConnection BAD_NETNAME 2 remote name %wZ Local %C authentication id %I64X\n",
-                                  &uniRemoteName,
-                                  ConnectCB->LocalName,
-                                  ConnectCB->AuthenticationId.QuadPart));
-                }
-                else
-                {
+	    if ( pConnection == NULL) {
 
-                    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                                  AFS_TRACE_LEVEL_VERBOSE,
-                                  "AFSAddConnection BAD_NETNAME 2 remote name %wZ Local (NULL) authentication id %I64X\n",
-                                  &uniRemoteName,
-                                  ConnectCB->AuthenticationId.QuadPart));
-                }
+		if( ConnectCB->LocalName != L'\0')
+		{
 
-                *ResultStatus = WN_BAD_NETNAME;
+		    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+				  AFS_TRACE_LEVEL_VERBOSE,
+				  "AFSAddConnection Bad Share Name remote name %wZ Local %C authentication id %I64X\n",
+				  &uniRemoteName,
+				  ConnectCB->LocalName,
+				  ConnectCB->AuthenticationId.QuadPart));
+		}
+		else
+		{
 
-                *ReturnOutputBufferLength = sizeof( ULONG);
+		    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+				  AFS_TRACE_LEVEL_VERBOSE,
+				  "AFSAddConnection Bad Share Name remote name %wZ Local (NULL) authentication id %I64X\n",
+				  &uniRemoteName,
+				  ConnectCB->AuthenticationId.QuadPart));
+		}
 
-                try_return( ntStatus = STATUS_SUCCESS);
-            }
+		*ResultStatus = WN_BAD_NETNAME;
 
-            uniRemoteName.Length = usLength;
-        }
-        else
-        {
+		*ReturnOutputBufferLength = sizeof( ULONG);
 
-            if( ConnectCB->LocalName != L'\0')
-            {
-
-                AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                              AFS_TRACE_LEVEL_VERBOSE,
-                              "AFSAddConnection BAD_NETNAME 3 remote name %wZ Local %C authentication id %I64X\n",
-                              &uniRemoteName,
-                              ConnectCB->LocalName,
-                              ConnectCB->AuthenticationId.QuadPart));
-            }
-            else
-            {
-
-                AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                              AFS_TRACE_LEVEL_VERBOSE,
-                              "AFSAddConnection BAD_NETNAME 3 remote name %wZ Local (NULL) authentication id %I64X\n",
-                              &uniRemoteName,
-                              ConnectCB->AuthenticationId.QuadPart));
-            }
-
-            *ResultStatus = WN_BAD_NETNAME;
-
-            *ReturnOutputBufferLength = sizeof( ULONG);
-
-            try_return( ntStatus = STATUS_SUCCESS);
-        }
+		try_return( ntStatus = STATUS_SUCCESS);
+	    }
+	}
 
         uniRemoteName.Length = (USHORT)ConnectCB->RemoteNameLength;
         uniRemoteName.MaximumLength = uniRemoteName.Length;
@@ -262,11 +276,12 @@ AFSAddConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
         uniRemoteName.Buffer = ConnectCB->RemoteName;
 
         //
-        // Strip off any trailing slashes
-        //
+	// Strip off any trailing slashes
+	//
 
-        if( uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
-        {
+	if( uniRemoteName.Length >= sizeof( WCHAR)
+	    && uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
+	{
 
             uniRemoteName.Length -= sizeof( WCHAR);
         }
@@ -423,16 +438,23 @@ AFSCancelConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
                       &pRDRDevExt->Specific.RDR.ProviderListLock,
                       PsGetCurrentThread()));
 
-        if( ConnectCB->AuthenticationId.QuadPart == 0)
-        {
+	ntStatus = AFSGetAuthenticationId(&ConnectCB->AuthenticationId);
 
-            ConnectCB->AuthenticationId = AFSGetAuthenticationId();
+	if ( !NT_SUCCESS( ntStatus))
+	{
 
-            AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                          AFS_TRACE_LEVEL_VERBOSE,
-                          "AFSCancelConnection Retrieved authentication id %I64X\n",
-                          ConnectCB->AuthenticationId.QuadPart));
-        }
+	    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			  AFS_TRACE_LEVEL_ERROR,
+			  "AFSCancelConnection Unable to retrieve authentication id %08lX\n",
+			  ntStatus));
+
+	    return ntStatus;
+	}
+
+	AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+		      AFS_TRACE_LEVEL_VERBOSE,
+		      "AFSCancelConnection Retrieved authentication id %I64X\n",
+		      ConnectCB->AuthenticationId.QuadPart));
 
         AFSAcquireExcl( &pRDRDevExt->Specific.RDR.ProviderListLock,
                         TRUE);
@@ -548,6 +570,24 @@ AFSGetConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
     __Enter
     {
 
+	ntStatus = AFSGetAuthenticationId(&ConnectCB->AuthenticationId);
+
+	if ( !NT_SUCCESS( ntStatus))
+	{
+
+	    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			  AFS_TRACE_LEVEL_ERROR,
+			  "AFSGetConnection Unable to retrieve authentication id %08lX\n",
+			  ntStatus));
+
+	    return ntStatus;
+	}
+
+	AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+		      AFS_TRACE_LEVEL_VERBOSE,
+		      "AFSGetConnection Retrieved authentication id %I64X\n",
+		      ConnectCB->AuthenticationId.QuadPart));
+
         if( ConnectCB->LocalName != L'\0')
         {
 
@@ -572,17 +612,6 @@ AFSGetConnection( IN AFSNetworkProviderConnectionCB *ConnectCB,
                       &pRDRDevExt->Specific.RDR.ProviderListLock,
                       PsGetCurrentThread()));
 
-        if( ConnectCB->AuthenticationId.QuadPart == 0)
-        {
-
-            ConnectCB->AuthenticationId = AFSGetAuthenticationId();
-
-            AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                          AFS_TRACE_LEVEL_VERBOSE,
-                          "AFSGetConnection Retrieved authentication id %I64X\n",
-                          ConnectCB->AuthenticationId.QuadPart));
-        }
-
         AFSAcquireShared( &pRDRDevExt->Specific.RDR.ProviderListLock,
                           TRUE);
 
@@ -688,16 +717,23 @@ AFSListConnections( IN OUT AFSNetworkProviderConnectionCB *ConnectCB,
 
         ulType = ConnectCB->Type;
 
-        if( ConnectCB->AuthenticationId.QuadPart == 0)
-        {
+	ntStatus = AFSGetAuthenticationId(&ConnectCB->AuthenticationId);
 
-            ConnectCB->AuthenticationId = AFSGetAuthenticationId();
+	if ( !NT_SUCCESS( ntStatus))
+	{
 
-            AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
-                          AFS_TRACE_LEVEL_VERBOSE,
-                          "AFSListConnections Retrieved authentication id %I64X\n",
-                          ConnectCB->AuthenticationId.QuadPart));
-        }
+	    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			  AFS_TRACE_LEVEL_ERROR,
+			  "AFSListConnection Unable to retrieve authentication id %08lX\n",
+			  ntStatus));
+
+	    return ntStatus;
+	}
+
+	AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+		      AFS_TRACE_LEVEL_VERBOSE,
+		      "AFSListConnections Retrieved authentication id %I64X\n",
+		      ConnectCB->AuthenticationId.QuadPart));
 
         liAuthenticationID.QuadPart = ConnectCB->AuthenticationId.QuadPart;
 
@@ -733,8 +769,9 @@ AFSListConnections( IN OUT AFSNetworkProviderConnectionCB *ConnectCB,
                            ConnectCB->RemoteName,
                            uniRemoteName.Length);
 
-            if( uniRemoteName.Buffer[ 0] == L'\\' &&
-                uniRemoteName.Buffer[ 1] == L'\\')
+	    if( uniRemoteName.Length >= 2 * sizeof( WCHAR)
+		&& uniRemoteName.Buffer[ 0] == L'\\'
+		&& uniRemoteName.Buffer[ 1] == L'\\')
             {
 
                 uniRemoteName.Buffer = &uniRemoteName.Buffer[ 1];
@@ -742,7 +779,8 @@ AFSListConnections( IN OUT AFSNetworkProviderConnectionCB *ConnectCB,
                 uniRemoteName.Length -= sizeof( WCHAR);
             }
 
-            if( uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
+	    if( uniRemoteName.Length >= sizeof( WCHAR)
+		&& uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
             {
 
                 uniRemoteName.Length -= sizeof( WCHAR);
@@ -1004,11 +1042,12 @@ AFSInitializeConnectionInfo( IN AFSProviderConnectionCB *Connection,
         uniName = Connection->RemoteName;
 
         //
-        // Strip of the double leading slash if there is one
+	// Strip off the double leading slash if there is one
         //
 
-        if( uniName.Buffer[ 0] == L'\\' &&
-            uniName.Buffer[ 1] == L'\\')
+	if( uniName.Length >= 2 * sizeof( WCHAR)
+	    && uniName.Buffer[ 0] == L'\\'
+	    && uniName.Buffer[ 1] == L'\\')
         {
 
             uniName.Buffer = &uniName.Buffer[ 1];
@@ -1294,6 +1333,22 @@ AFSEnumerateConnection( IN OUT AFSNetworkProviderConnectionCB *ConnectCB,
 
                 try_return( ntStatus);
             }
+
+	    //
+	    // Here we have a match on the case insensitive lookup for the name. If there
+	    // Is more than one link entry for this node then fail the lookup request
+	    //
+
+	    if( !BooleanFlagOn( pShareDirEntry->Flags, AFS_DIR_ENTRY_CASE_INSENSTIVE_LIST_HEAD) ||
+		pShareDirEntry->CaseInsensitiveList.fLink != NULL)
+	    {
+
+		AFSReleaseResource( AFSGlobalRoot->ObjectInformation.Specific.Directory.DirectoryNodeHdr.TreeLock);
+
+		pShareDirEntry = NULL;
+
+		try_return(ntStatus = STATUS_OBJECT_NAME_COLLISION);
+	    }
         }
 
         lCount = InterlockedIncrement( &pShareDirEntry->DirOpenReferenceCount);
@@ -1443,7 +1498,6 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
     NTSTATUS ntStatus = STATUS_SUCCESS;
     AFSProviderConnectionCB *pConnection = NULL, *pBestMatch = NULL;
     UNICODE_STRING uniRemoteName, uniServerName, uniShareName, uniRemainingPath, uniFullName, uniRemainingPathLocal;
-    USHORT usNameLen = 0, usMaxNameLen = 0;
     BOOLEAN bEnumerationEntry = FALSE;
     AFSDeviceExt *pRDRDevExt = (AFSDeviceExt *)AFSRDRDeviceObject->DeviceExtension;
 
@@ -1466,6 +1520,24 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
         uniRemoteName.MaximumLength = uniRemoteName.Length + sizeof( WCHAR);
         uniRemoteName.Buffer = (WCHAR *)ConnectCB->RemoteName;
 
+	ntStatus = AFSGetAuthenticationId(&ConnectCB->AuthenticationId);
+
+	if ( !NT_SUCCESS( ntStatus))
+	{
+
+	    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+			  AFS_TRACE_LEVEL_ERROR,
+			  "AFSGetConnectionInfo Unable to retrieve authentication id %08lX\n",
+			  ntStatus));
+
+	    return ntStatus;
+	}
+
+	AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+		      AFS_TRACE_LEVEL_VERBOSE,
+		      "AFSGetConnectionInfo Retrieved authentication id %I64X\n",
+		      ConnectCB->AuthenticationId.QuadPart));
+
         if( ConnectCB->LocalName != L'\0')
         {
 
@@ -1498,8 +1570,9 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
 
         uniFullName = uniRemoteName;
 
-        if( uniRemoteName.Buffer[ 0] == L'\\' &&
-            uniRemoteName.Buffer[ 1] == L'\\')
+	if( uniRemoteName.Length >= 2 * sizeof( WCHAR)
+	    && uniRemoteName.Buffer[ 0] == L'\\'
+	    && uniRemoteName.Buffer[ 1] == L'\\')
         {
 
             uniRemoteName.Buffer = &uniRemoteName.Buffer[ 1];
@@ -1507,7 +1580,8 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
             uniRemoteName.Length -= sizeof( WCHAR);
         }
 
-        if( uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
+	if( uniRemoteName.Length >= sizeof( WCHAR)
+	    && uniRemoteName.Buffer[ (uniRemoteName.Length/sizeof( WCHAR)) - 1] == L'\\')
         {
 
             uniRemoteName.Length -= sizeof( WCHAR);
@@ -1539,7 +1613,7 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
                                      TRUE) != 0)
         {
 
-            try_return( ntStatus = STATUS_INVALID_PARAMETER);
+	    try_return( ntStatus = STATUS_BAD_NETWORK_NAME);
         }
 
         if ( uniRemainingPath.Length > 0 )
@@ -1604,9 +1678,22 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
         else
         {
 
-            //
-            // See if we can locate it on our connection list
-            //
+	    USHORT usNameLen = 0, usMaxNameLen = 0;
+
+	    //
+	    // AFSGetConnectionInfo() is called to generate responses for
+	    // NPGetResourceInformation and NPGetConnectionPerformance.
+	    // The former can be called with a Connection->RemoteName that
+	    // consists of \\server\share\dir1\dir2\...\dirN where one or
+	    // all of the directories do not have to be processed by the
+	    // network provider.  For example, one of the directories might
+	    // be a reparse point that redirects to another network provider.
+	    // It might also be the case that a directory might be in the
+	    // \\afs file namespace but not be accessible with the current
+	    // credentials.  That doesn't make the connection invalid.
+	    // As such the network provider is not required to validate the
+	    // entire RemoteName.  This can result in false positives.
+	    //
 
             pConnection = pRDRDevExt->Specific.RDR.ProviderConnectionList;
 
@@ -1615,19 +1702,27 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
                           "AFSGetConnectionInfo Searching for full name %wZ\n",
                           &uniFullName));
 
-            while( pConnection != NULL)
+	    while (pConnection != NULL)
             {
 
-                if( usMaxNameLen < pConnection->RemoteName.Length &&
-                    pConnection->RemoteName.Length <= uniFullName.Length)
+		//
+		// A partial match can be valid but it must occur on a
+		// component boundary.
+		//
+
+		if (pConnection->AuthenticationId.QuadPart == ConnectCB->AuthenticationId.QuadPart &&
+		     usMaxNameLen < pConnection->RemoteName.Length &&
+		     (pConnection->RemoteName.Length == uniFullName.Length ||
+		       pConnection->RemoteName.Length < uniFullName.Length &&
+		       (uniFullName.Buffer[pConnection->RemoteName.Length/sizeof(WCHAR)] == L'\\' ||
+			 uniFullName.Buffer[pConnection->RemoteName.Length/sizeof(WCHAR)] == L'/')))
                 {
 
                     usNameLen = uniFullName.Length;
 
                     uniFullName.Length = pConnection->RemoteName.Length;
 
-                    if( pConnection->AuthenticationId.QuadPart == ConnectCB->AuthenticationId.QuadPart &&
-                        RtlCompareUnicodeString( &uniFullName,
+		    if (RtlCompareUnicodeString( &uniFullName,
                                                  &pConnection->RemoteName,
                                                  TRUE) == 0)
                     {
@@ -1660,8 +1755,7 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
                               "AFSGetConnectionInfo Using best match for %wZ\n",
                               &pConnection->RemoteName));
             }
-
-            if( pConnection == NULL)
+	    else
             {
 
                 //
@@ -1669,7 +1763,16 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
                 //
 
                 pConnection = AFSLocateEnumRootEntry( &uniShareName);
-            }
+
+		if (pConnection != NULL)
+		{
+
+		    AFSDbgTrace(( AFS_SUBSYSTEM_NETWORK_PROVIDER,
+				  AFS_TRACE_LEVEL_VERBOSE,
+				  "AFSGetConnectionInfo Using share connection %wZ\n",
+				  &pConnection->RemoteName));
+		}
+	    }
         }
 
         if( pConnection == NULL)
@@ -1706,7 +1809,7 @@ AFSGetConnectionInfo( IN AFSNetworkProviderConnectionCB *ConnectCB,
                               "AFSGetConnectionInfo Evaluation Failed share name %wZ\n",
                               uniShareName));
 
-                try_return( ntStatus = STATUS_INVALID_PARAMETER);
+		try_return( ntStatus = STATUS_BAD_NETWORK_NAME);
 
             }
 
