@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2008, 2009, 2010, 2011 Kernel Drivers, LLC.
- * Copyright (c) 2009, 2010, 2011 Your File System, Inc.
+ * Copyright (c) 2009, 2010, 2011, 2015 Your File System, Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -193,6 +193,8 @@ typedef struct _AFS_OBJECT_INFORMATION_CB
 
     LONG                      ObjectReferenceCount;
 
+    LONG                      ObjectReferences[ AFS_OBJECT_REFERENCE_MAX];
+
     AFSNonPagedObjectInfoCB  *NonPagedInfo;
 
     //
@@ -205,7 +207,7 @@ typedef struct _AFS_OBJECT_INFORMATION_CB
     // Parent object information
     //
 
-    struct _AFS_OBJECT_INFORMATION_CB   *ParentObjectInformation;
+    AFSFileID	            ParentFileId;
 
     //
     // Pointer to the current Fcb, if available
@@ -321,7 +323,13 @@ typedef struct _AFS_NON_PAGED_VOLUME_CB
 
     ERESOURCE           DirectoryNodeHdrLock;
 
-}AFSNonPagedVolumeCB;
+    //
+    // Volume worker thread
+    //
+
+    AFSWorkQueueContext       VolumeWorkerContext;
+
+} AFSNonPagedVolumeCB;
 
 typedef struct _AFS_VOLUME_CB
 {
@@ -350,6 +358,8 @@ typedef struct _AFS_VOLUME_CB
 
     LONG                      VolumeReferenceCount;
 
+    LONG                      VolumeReferences[ AFS_VOLUME_REFERENCE_MAX];
+
     //
     // Object information tree
     //
@@ -378,12 +388,6 @@ typedef struct _AFS_VOLUME_CB
 
     AFSFcb                   *RootFcb;
 
-    //
-    // Volume worker thread
-    //
-
-    AFSWorkQueueContext       VolumeWorkerContext;
-
     //
     // Volume information
     //
@@ -433,6 +437,12 @@ typedef struct _AFS_DIRECTORY_CB
 
     LONG             DirOpenReferenceCount;
 
+    //
+    // Current count of reference from Name Array entries
+    //
+
+    LONG             NameArrayReferenceCount;
+
     //
     // File index used in directory enumerations
     //
@@ -656,6 +666,16 @@ typedef struct _AFS_WORK_ITEM
 
         } Invalidate;
 
+	struct
+	{
+	    PETHREAD	peThread;
+
+	    PEPROCESS	peProcess;
+
+	    LARGE_INTEGER AuthId;
+
+	} GetAuthId;
+
         struct
         {
             char     Context[ 1];
