@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -11,8 +11,9 @@
 #include <ws2tcpip.h>
 
 extern "C" {
+#include <afsconfig.h>
 #include <afs/param.h>
-#include <afs/stds.h>
+#include <roken.h>
 }
 
 #include "svrmgr.h"
@@ -459,9 +460,9 @@ BOOL CALLBACK Services_PickLog_DlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM l
                }
             break;
 
-         case WM_NOTIFY: 
+         case WM_NOTIFY:
             switch (((LPNMHDR)lp)->code)
-               { 
+               {
                case FLN_ITEMSELECT:
                   if (IsWindowEnabled (GetDlgItem (hDlg, IDC_VIEWLOG_SERVER)))
                      {
