@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -664,13 +664,13 @@ void UserProp_General_OnApply (HWND hDlg)
    if (!IsDlgButtonChecked (hDlg, IDC_USER_PWEXPIRES))
       lpp->cdayPwExpires = 0;
    else
-      lpp->cdayPwExpires = SP_GetPos (GetDlgItem (hDlg, IDC_USER_PWEXPIRATION));
+      lpp->cdayPwExpires = (LONG) SP_GetPos (GetDlgItem (hDlg, IDC_USER_PWEXPIRATION));
    lpp->fPwExpires_Mixed = (IsDlgButtonChecked (hDlg, IDC_USER_PWEXPIRES) == BST_INDETERMINATE);
 
    if (!IsDlgButtonChecked (hDlg, IDC_USER_FAILLOCK))
       lpp->cFailLock = 0;
    else
-      lpp->cFailLock = SP_GetPos (GetDlgItem (hDlg, IDC_USER_FAILLOCK_COUNT));
+      lpp->cFailLock = (LONG) SP_GetPos (GetDlgItem (hDlg, IDC_USER_FAILLOCK_COUNT));
    lpp->fFailLock_Mixed = (IsDlgButtonChecked (hDlg, IDC_USER_FAILLOCK) == BST_INDETERMINATE);
 
    if (!IsDlgButtonChecked (hDlg, IDC_USER_FAILLOCK_FINITE))
@@ -1040,7 +1040,7 @@ void UserProp_Advanced_OnApply (HWND hDlg)
       if (!IsDlgButtonChecked (hDlg, IDC_USER_GROUP_HASQUOTA))
          lpp->cGroupQuota = cGROUPQUOTA_INFINITE;
       else // (IsDlgButtonChecked (hDlg, IDC_USER_GROUP_HASQUOTA))
-         lpp->cGroupQuota = SP_GetPos (GetDlgItem (hDlg, IDC_USER_GROUP_QUOTA));
+         lpp->cGroupQuota = (LONG) SP_GetPos (GetDlgItem (hDlg, IDC_USER_GROUP_QUOTA));
       lpp->fGroupQuota_Mixed = (IsDlgButtonChecked (hDlg, IDC_USER_GROUP_HASQUOTA) == BST_INDETERMINATE);
       }
 
@@ -1338,7 +1338,7 @@ void UserProp_Member_PopulateList (HWND hDlg)
       {
       if (IsDlgButtonChecked (hDlg, IDC_USER_SHOW_MEMBER))
          {
-         if (!lpp->pUserList) 
+         if (!lpp->pUserList)
             GetString (szTitle, IDS_NEWMACHINE_SHOW_MEMBER_TITLE);
          else if (lpp->pUserList->cEntries == 1)
             GetString (szTitle, IDS_MACHINE_SHOW_MEMBER_TITLE);
@@ -1357,7 +1357,7 @@ void UserProp_Member_PopulateList (HWND hDlg)
       {
       if (IsDlgButtonChecked (hDlg, IDC_USER_SHOW_MEMBER))
          {
-         if (!lpp->pUserList) 
+         if (!lpp->pUserList)
             GetString (szTitle, IDS_NEWUSER_SHOW_MEMBER_TITLE);
          else if (lpp->pUserList->cEntries == 1)
             GetString (szTitle, IDS_USER_SHOW_MEMBER_TITLE);
