@@ -11,8 +11,9 @@
 #include <ws2tcpip.h>
 
 extern "C" {
+#include <afsconfig.h>
 #include <afs/param.h>
-#include <afs/stds.h>
+#include <roken.h>
 #include <afs/fs_utils.h>
 }
 
@@ -135,11 +136,6 @@ BOOL CALLBACK WizCommon_DlgProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
                break;
            }
         break;
-
-      case WM_HELP:
-         if (l.idh)
-            WinHelp (GetParent(hDlg), g.szHelpFile, HELP_CONTEXT, l.idh);
-         break;
      }
    return FALSE;
 }
