@@ -28,7 +28,7 @@ BOOL ListMount(CStringArray& files);
 BOOL MakeMount(const CString& strDir, const CString& strVolName, const CString& strCellName, BOOL bRW);
 BOOL RemoveMount(CStringArray& files);
 BOOL RemoveSymlink(const CString& symlink);
-BOOL GetVolumeInfo(CString strFile, CVolInfo& volInfo);
+BOOL GetVolumeInfo(CString strFile, CVolInfo& volInfo, BOOL bFollow=TRUE);
 BOOL SetVolInfo(CVolInfo& volInfo);
 enum WHICH_CELLS { LOCAL_CELL = 0, SPECIFIC_CELL = 1, ALL_CELLS = 2 };
 BOOL CheckServers(const CString& strCellName, WHICH_CELLS nCellsToCheck, BOOL bFast);
@@ -40,11 +40,11 @@ BOOL IsMountPoint(const CString& name);
 UINT MakeSymbolicLink(const CString&,const CString&);
 void ListSymbolicLinkPath(CString&,CString&,UINT nlenPath);
 BOOL ListSymlink(CStringArray& files);
-CString GetCellName(const CString& strPath);
-CString GetServer(const CString& strPath);
-void GetServers( const CString& strPath, CStringArray& servers );
-CString GetOwner(const CString& strPath);
-CString GetGroup(const CString& strPath);
+CString GetCellName(const CString& strPath, BOOL bFollow = TRUE);
+CString GetServer(const CString& strPath, BOOL bFollow = TRUE);
+void GetServers( const CString& strPath, CStringArray& servers, BOOL bFollow = TRUE );
+CString GetOwner(const CString& strPath, BOOL bFollow = TRUE);
+CString GetGroup(const CString& strPath, BOOL bFollow = TRUE);
 BOOL GetUnixModeBits(const CString& strPath, CString& user, CString& group, CString& other, CString& suid);
 void SetUnixModeBits(const CStringArray& files, const CString& user, const CString& group, const CString& other, const CString& suid);
 CString GetMountpoint(const CString& strPath);
