@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -185,7 +185,7 @@ void cdecl FormatMultiString (LPTSTR *ppszTarget, BOOL fAddHead, LPCTSTR pszTemp
    va_list arg;
    //if (pszFormat != NULL)
       va_start (arg, pszFormat);
-   vFormatMultiString (ppszTarget, fAddHead, (LONG)pszTemplate, pszFormat, arg);
+   vFormatMultiString (ppszTarget, fAddHead, PtrToLong(pszTemplate), pszFormat, arg);
 }
 
 void cdecl FormatMultiString (LPTSTR *ppszTarget, BOOL fAddHead, int idsTemplate, LPCTSTR pszFormat, ...)
@@ -198,7 +198,7 @@ void cdecl FormatMultiString (LPTSTR *ppszTarget, BOOL fAddHead, int idsTemplate
 
 void cdecl vFormatMultiString (LPTSTR *ppszTarget, BOOL fAddHead, LPCTSTR pszTemplate, LPCTSTR pszFormat, va_list arg)
 {
-   vFormatMultiString (ppszTarget, fAddHead, (LONG)pszTemplate, pszFormat, arg);
+   vFormatMultiString (ppszTarget, fAddHead, PtrToLong(pszTemplate), pszFormat, arg);
 }
 
 void cdecl vFormatMultiString (LPTSTR *ppszTarget, BOOL fAddHead, int idsTemplate, LPCTSTR pszFormat, va_list arg)
@@ -216,7 +216,7 @@ LPTSTR cdecl FormatString (LPCTSTR psz, LPCTSTR pszFmt, ...)
    va_list arg;
    //if (pszFmt != NULL)
       va_start (arg, pszFmt);
-   return vFormatString ((LONG)psz, pszFmt, arg);
+   return vFormatString (PtrToLong(psz), pszFmt, arg);
 }
 
 LPTSTR cdecl FormatString (int ids, LPCTSTR pszFmt, ...)
@@ -229,7 +229,7 @@ LPTSTR cdecl FormatString (int ids, LPCTSTR pszFmt, ...)
 
 LPTSTR cdecl vFormatString (LPCTSTR psz, LPCTSTR pszFmt, va_list arg)
 {
-   return vFormatString ((LONG)psz, pszFmt, arg);
+   return vFormatString (PtrToLong(psz), pszFmt, arg);
 }
 
 LPTSTR cdecl vFormatString (int ids, LPCTSTR pszFmt, va_list arg)
@@ -273,7 +273,7 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
    LPTSTR   pszOut = NULL;
    LPTSTR   pchOut;
    LPTSTR   pszTemplate;
-   LONG     cch;
+   size_t   cch;
    int      nArgs;
    int      argno;
    TCHAR    szFmt[ cchRESOURCE ];
@@ -283,16 +283,16 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
 
    if (HIWORD(pszSource) != 0)	// It's a string
       {
-      pszTemplate = (LPTSTR)pszSource;
+      pszTemplate = (LPTSTR)LongToPtr(pszSource);
       }
    else	// It's a message
       {
-      cch = GetStringLength ((int)pszSource);
+      cch = GetStringLength((INT)pszSource);
 
       if ((pszTemplate = AllocateString (1+cch)) == NULL)
          return NULL;
 
-      GetString (pszTemplate, (int)pszSource, cch);
+      GetString (pszTemplate, (int)pszSource, (INT)cch);
       }
 
             //
@@ -336,7 +336,7 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
 
    if (apszArgs == NULL)
       {
-      if (pszSource != (LONG)pszTemplate)
+      if (pszSource != PtrToLong(pszTemplate))
          FreeString (pszTemplate);
       return NULL;
       }
@@ -349,7 +349,7 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
 
    for (argno = 0; pszFmt && *pszFmt; argno++)
       {
-      LONG     cchMin;
+      size_t   cchMin;
       vartype  vt;
 
       double   arg_f;
@@ -511,7 +511,7 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
             cch = cchMaxNUMBER;
             break;
 
-         case vtSTRINGA:   
+         case vtSTRINGA:
             {
             LPSTR arg_pszA = va_arg (arg, LPSTR);
 
@@ -524,7 +524,7 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
             break;
             }
 
-         case vtSTRINGW:   
+         case vtSTRINGW:
             {
             LPWSTR arg_pszW = va_arg (arg, LPWSTR);
 
@@ -547,7 +547,7 @@ LPTSTR cdecl vFormatString (LONG pszSource, LPCTSTR pszFmt, va_list arg)
                {
                if ((arg_psz = AllocateString (cch)) == NULL)
                   goto lblDONE;
-               GetString (arg_psz, arg_ids, cch);
+               GetString (arg_psz, arg_ids, (INT)cch);
                }
 
             cch = lstrlen(arg_psz);
@@ -785,7 +785,7 @@ BOOL FormatElapsed (LPTSTR pszTarget, LPTSTR pszFormatUser, SYSTEMTIME *pst)
       lstrcpy (szTimeSep, TEXT(":"));
 
    TCHAR szElapsed[ cchRESOURCE ];
-   wsprintf (szElapsed, TEXT("%02lu%s%02lu%s%02lu"), 
+   wsprintf (szElapsed, TEXT("%02lu%s%02lu%s%02lu"),
              pst->wHour + (pst->wDay * 24),
              szTimeSep,
              pst->wMinute,
@@ -823,21 +823,21 @@ BOOL FormatTime (LPTSTR pszTarget, LPTSTR pszFormatUser, SYSTEMTIME *pst, BOOL f
       }
    else
       {
-      GetTimeFormat (LOCALE_USER_DEFAULT, 0,              &lt, NULL, szTime, cchRESOURCE);
-      GetDateFormat (LOCALE_USER_DEFAULT, DATE_SHORTDATE, &lt, NULL, szDate, cchRESOURCE);
+      GetTimeFormat (LOCALE_USER_DEFAULT, 0, &lt, TEXT("HH:mm:ss"), szTime, cchRESOURCE);
+      GetDateFormat (LOCALE_USER_DEFAULT, 0, &lt, TEXT("yyyy-MM-dd"), szDate, cchRESOURCE);
 
       if (fShowTime && fShowDate)
          {
-         lstrcat (szTime, TEXT(" "));
-         lstrcat (szTime, szDate);
+         lstrcat (szDate, TEXT(" "));
+         lstrcat (szDate, szTime);
          }
-      else if (fShowDate && !fShowTime)
+      else if (!fShowDate && fShowTime)
          {
-         lstrcpy (szTime, szDate);
+         lstrcpy (szDate, szTime);
          }
       }
 
-   wsprintf (pszTarget, FixFormatString (pszFormatUser), szTime);
+   wsprintf (pszTarget, FixFormatString (pszFormatUser), szDate);
    return rc;
 }
 
@@ -1423,7 +1423,7 @@ void CopyUnicodeToAnsi (LPSTR pszTargetA, LPCWSTR pszOriginalW, size_t cchMax)
 
    UINT cpTarget = CP_ACP;
    BOOL fDefault = FALSE;
-   size_t cchOut = WideCharToMultiByte (cpTarget, 0, pszOriginalW, cchSource-1, pszTargetA, cchMax * 2, TEXT(" "), &fDefault);
+   size_t cchOut = WideCharToMultiByte (cpTarget, 0, pszOriginalW, (INT)cchSource-1, pszTargetA, (INT)cchMax * 2, " ", &fDefault);
    pszTargetA[ cchOut ] = 0;
 }
 
@@ -1549,7 +1549,7 @@ LPTSTR UnicodeToString (LPCWSTR pszOriginalW)
     LPTSTR pszTarget;
     if ((pszTarget = AllocateString (1+lstrlenW(pszOriginalW))) != NULL) {
 #ifdef UNICODE
-        lstrcpyW ((LPWSTR)pszTargetW, (LPWSTR)pszOriginal);
+        lstrcpyW ((LPWSTR)pszTarget, (LPWSTR)pszOriginalW);
 #else
         CopyUnicodeToAnsi (pszTarget, pszOriginalW);
 #endif
