@@ -1,19 +1,19 @@
-/* 
+/*
    Unix SMB/CIFS implementation.
    SMB torture tester
    Copyright (C) Andrew Tridgell 1997-1998
    Copyright (C) Richard Sharpe  2002
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -53,9 +53,9 @@ void DumpAFSLog(char * HostName, int LogID);
 int  FindHandle(int handle);
 int  GetFileList(char *Mask, void (*fn)(file_info *, const char *, void *), void *state);
 BOOL GetFileInfo(char *FileName, HANDLE fd, uint16 *mode, size_t *size,
-		        time_t *c_time, time_t *a_time, time_t *m_time, 
+		        time_t *c_time, time_t *a_time, time_t *m_time,
 		        time_t *w_time);
-BOOL GetPathInfo(const char *fname, time_t *c_time, time_t *a_time, time_t *m_time, 
+BOOL GetPathInfo(const char *fname, time_t *c_time, time_t *a_time, time_t *m_time,
 		         size_t *size, uint16 *mode);
 int  LeaveThread(int status, char *Reason, int cmd);
 void StartFirstTimer();
@@ -99,7 +99,7 @@ int nb_unlink(char *fname)
     EndFirstTimer(CMD_UNLINK, 1);
     if (!rc)
     {
-        LeaveThread(0, "", CMD_UNLINK);
+        LeaveThread(gle, "", CMD_UNLINK);
         sprintf(temp, "FILE: DeleteFile %s failed GLE(0x%x)\n", path, gle);
         if (verbose)
             printf("%s", temp);
@@ -153,6 +153,8 @@ int nb_Xrmdir(char *Directory, char *type)
         sprintf(temp, "rmdir failed on %s\n", command);
         LeaveThread(rc, temp, CMD_XRMDIR);
         sprintf(temp, "FAILURE: Thread %d - Xrmdir failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -188,6 +190,8 @@ int nb_Mkdir(char *Directory)
         sprintf(temp,  "mkdir failed on %s\n", command);
         LeaveThread(rc, temp, CMD_MKDIR);
         sprintf(temp, "ERROR: Thread %d - mkdir failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -226,6 +230,8 @@ int nb_Attach(char *Locker, char *Drive)
         sprintf(pExitStatus->Reason, "attach failed on %s\n", command);
         pExitStatus->ExitStatus = rc;
         sprintf(temp, "ERROR: Thread %d - attach failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
     }
     EndFirstTimer(CMD_ATTACH, 1);
@@ -266,6 +272,8 @@ int nb_Detach(char *Name, char *type)
         sprintf(temp, "detach failed on %s\n", command);
         LeaveThread(rc, temp, CMD_DETACH);
         sprintf(temp, "ERROR: Thread %d - detach failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -295,7 +303,7 @@ int nb_CreateFile(char *path, DWORD size)
     strcpy(NewPath, path);
 
     StartFirstTimer();
-    fHandle = CreateFile(NewPath, 
+    fHandle = CreateFile(NewPath,
                          GENERIC_READ | GENERIC_WRITE | STANDARD_RIGHTS_ALL,
                          FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
                          NULL,
@@ -307,8 +315,10 @@ int nb_CreateFile(char *path, DWORD size)
     {
         EndFirstTimer(CMD_CREATEFILE, 0);
         sprintf(temp, "Create file failed on \"%s\" GLE(0x%x)\n", NewPath, gle);
-        LeaveThread(0, temp, CMD_CREATEFILE);
+        LeaveThread(gle, temp, CMD_CREATEFILE);
         sprintf(temp, "ERROR: Thread %d - Create file failed on \"%s\" GLE(0x%x)\n", ProcessNumber, NewPath, gle);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -392,6 +402,8 @@ int nb_DeleteFile(char *path)
         sprintf(temp, "del failed on \"%s\"\n", NewPath);
         LeaveThread(rc, temp, CMD_DELETEFILES);
         sprintf(temp, "ERROR: Thread %d - del failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -427,6 +439,8 @@ int nb_xcopy(char *Source, char *Destination)
         sprintf(temp, "xcopy failed on %s\n", command);
         LeaveThread((int)rc, temp, CMD_XCOPY);
         sprintf(temp, "FAIURE: Thread %d - xcopy failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -461,6 +475,8 @@ int nb_Move(char *Source, char *Destination)
         sprintf(temp, "move failed on \"%s\"\n", command);
         LeaveThread(rc, temp, CMD_MOVE);
         sprintf(temp, "FAILURE: Thread %d - move failed on \"%s\"\n", ProcessNumber, command);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
     }
@@ -476,6 +492,7 @@ int nb_createx(char *fname, unsigned create_options, unsigned create_disposition
     char    FileName[128];
     char    temp[512];
     pstring path;
+    DWORD gle;
 
     sprintf(FileName, "Thread_%05d.log", ProcessNumber);
 
@@ -491,19 +508,20 @@ int nb_createx(char *fname, unsigned create_options, unsigned create_disposition
     }
 
     StartFirstTimer();
-    fd = CreateObject(path, 
+    fd = CreateObject(path,
                        desired_access,
                        0x0,
-                       FILE_SHARE_READ|FILE_SHARE_WRITE, 
-                       create_disposition, 
+                       FILE_SHARE_READ|FILE_SHARE_WRITE,
+                       create_disposition,
                        create_options);
 
     if (fd == INVALID_HANDLE_VALUE && handle != -1)
     {
+        gle = GetLastError();
         if (create_options & FILE_DIRECTORY_FILE)
         {
             EndFirstTimer(CMD_NTCREATEX, 0);
-            LeaveThread(0, "", CMD_NTCREATEX);
+            LeaveThread(gle, "", CMD_NTCREATEX);
             sprintf(temp, "Directory: unable to create directory %s\n", path);
             if (verbose)
                 printf("%s", temp);
@@ -513,7 +531,7 @@ int nb_createx(char *fname, unsigned create_options, unsigned create_disposition
         else
         {
             EndFirstTimer(CMD_NTCREATEX, 0);
-            LeaveThread(0, "", CMD_NTCREATEX);
+            LeaveThread(gle, "", CMD_NTCREATEX);
             sprintf(temp, "File: unable to create file %s\n", path);
             if (verbose)
                 printf("%s", temp);
@@ -534,19 +552,19 @@ int nb_createx(char *fname, unsigned create_options, unsigned create_disposition
     if (fd == INVALID_HANDLE_VALUE && handle == -1)
         return(0);
 
-    for (i = 0; i < MAX_FILES; i++) 
+    for (i = 0; i < MAX_FILES; i++)
     {
-        if (ftable[i].handle == 0) 
+        if (ftable[i].handle == 0)
             break;
     }
-    if (i == MAX_FILES) 
+    if (i == MAX_FILES)
     {
         printf("(%d) file table full for %s\n", LineCount, path);
         return(LeaveThread(1, "file table is full\n", CMD_NTCREATEX));
     }
     ftable[i].handle = handle;
     ftable[i].fd = fd;
-    if (ftable[i].name) 
+    if (ftable[i].name)
         free(ftable[i].name);
     ftable[i].name = strdup(path);
     ftable[i].reads = ftable[i].writes = 0;
@@ -560,6 +578,7 @@ int nb_writex(int handle, int offset, int size, int ret_size)
     char    FileName[128];
     char    temp[512];
     unsigned char magic = (unsigned char)getpid();
+    DWORD gle;
 
     sprintf(FileName, "Thread_%05d.log", ProcessNumber);
 
@@ -573,10 +592,11 @@ int nb_writex(int handle, int offset, int size, int ret_size)
         return(-1);
     StartFirstTimer();
     status = nb_write(ftable[i].fd, IoBuffer, offset, size);
-    if (status != ret_size) 
+    if (status != ret_size)
     {
+        gle = GetLastError();
         EndFirstTimer(CMD_WRITEX, 0);
-		LeaveThread(0, "", CMD_WRITEX);
+        LeaveThread(gle, "", CMD_WRITEX);
         if (status == 0)
             sprintf(temp, "File: %s. wrote %d bytes, got %d bytes\n", ftable[i].name, size, status);
         if (status == -1)
@@ -584,6 +604,8 @@ int nb_writex(int handle, int offset, int size, int ret_size)
         if (verbose)
             printf("%s", temp);
         nb_close(handle);
+        if (verbose)
+            printf("%s", temp);
         LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
         return(-1);
 	}
@@ -652,7 +674,7 @@ int nb_readx(int handle, int offset, int size, int ret_size)
     if ((ret != size) && (ret != ret_size))
     {
         EndFirstTimer(CMD_READX, 0);
-        LeaveThread(0, "", CMD_READX);
+        LeaveThread(gle, "", CMD_READX);
         if (ret == 0)
             sprintf(temp, "File: read failed on index=%d, offset=%d ReadSize=%d ActualRead=%d handle=%p GLE(0x%x)\n",
                     handle, offset, size, ret, ftable[i].fd, gle);
@@ -675,6 +697,7 @@ int nb_close(int handle)
     int     ret;
     char    FileName[128];
     char    temp[512];
+    DWORD   gle;
 
     sprintf(FileName, "Thread_%05d.log", ProcessNumber);
 
@@ -682,11 +705,12 @@ int nb_close(int handle)
         return(0);
 
     StartFirstTimer();
-    ret = nb_close1(ftable[i].fd); 
+    ret = nb_close1(ftable[i].fd);
+    gle = GetLastError();
     EndFirstTimer(CMD_CLOSE, ret);
-    if (!ret) 
+    if (!ret)
     {
-        LeaveThread(0, "", CMD_CLOSE);
+        LeaveThread(gle, "", CMD_CLOSE);
         sprintf(temp, "(%d) close failed on handle %d\n", LineCount, handle);
         if (verbose)
             printf("%s", temp);
@@ -696,10 +720,10 @@ int nb_close(int handle)
 
     ftable[i].handle = 0;
     ftable[i].fd = 0;
-    if (ftable[i].name) 
+    if (ftable[i].name)
         free(ftable[i].name);
     ftable[i].name = NULL;
-    return(0);   
+    return(0);
 }
 
 int nb_rmdir(char *fname)
@@ -722,7 +746,7 @@ int nb_rmdir(char *fname)
 
     if (!rc)
     {
-        LeaveThread(0, "", CMD_RMDIR);
+        LeaveThread(gle, "", CMD_RMDIR);
         sprintf(temp, "Directory: RemoveDirectory %s failed GLE(0x%x)\n", fname, gle);
         if (verbose)
             printf("%s", temp);
@@ -746,7 +770,7 @@ int nb_rename(char *old, char *New)
     strcpy(opath, AfsLocker);
     strcat(opath, old);
     strcpy(npath, AfsLocker);
-    strcat(npath, New); 
+    strcat(npath, New);
 
     StartFirstTimer();
     rc = MoveFileEx(opath, npath, MOVEFILE_REPLACE_EXISTING | MOVEFILE_WRITE_THROUGH);
@@ -755,7 +779,7 @@ int nb_rename(char *old, char *New)
 
     if (!rc)
     {
-        LeaveThread(0, "", CMD_RENAME);
+        LeaveThread(gle, "", CMD_RENAME);
         sprintf(temp, "File: rename %s %s failed GLE(0x%x)\n", old, New, gle);
         if (verbose)
             printf("%s", temp);
@@ -765,8 +789,8 @@ int nb_rename(char *old, char *New)
     return(0);
 }
 
-/* 
- * Type is used to determine whether the file is expected 
+/*
+ * Type is used to determine whether the file is expected
  * to exist or not.  It is overloaded (temporarily) to control
  * Flag which indicates whether an error is treated as an error
  * or not.  The StreamFiles.txt script does not have the Type
@@ -825,7 +849,7 @@ int nb_qpathinfo(char *fname, int Type)
         if (!rc)
         {
             EndFirstTimer(CMD_QUERY_PATH_INFO, 0);
-            LeaveThread(0, "", CMD_QUERY_PATH_INFO);
+            LeaveThread(gle, "", CMD_QUERY_PATH_INFO);
             sprintf(temp, "File: qpathinfo failed for %s type %d GLE(0x%x)\n", path, Type, gle);
             if (verbose)
                 printf("%s", temp);
@@ -856,7 +880,7 @@ int nb_qfileinfo(int handle)
     if (!rc)
     {
         EndFirstTimer(CMD_QUERY_FILE_INFO, 0);
-        LeaveThread(0, "", CMD_QUERY_FILE_INFO);
+        LeaveThread(gle, "", CMD_QUERY_FILE_INFO);
         sprintf(temp, "File: qfileinfo failed for %s GLE(0x%x)\n", ftable[i].name, gle);
         if (verbose)
             printf("%s", temp);
@@ -882,7 +906,7 @@ int nb_qfsinfo(int level)
     ULARGE_INTEGER TotalNumberOfBytes;
     ULARGE_INTEGER TotalNumberOfFreeBytes;
     DWORD   gle;
- 
+
     sprintf(FileName, "Thread_%05d.log", ProcessNumber);
     sprintf(Path, "%s\\%s%05d", AfsLocker, HostName, LogID);
 
@@ -894,7 +918,7 @@ int nb_qfsinfo(int level)
     if (!rc)
     {
         EndFirstTimer(CMD_QUERY_FS_INFO, 0);
-        LeaveThread(0, "", CMD_QUERY_FS_INFO);
+        LeaveThread(gle, "", CMD_QUERY_FS_INFO);
         sprintf(temp, "File: Disk free space failed GLE(0x%x)\n", gle);
         if (verbose)
             printf("%s", temp);
@@ -966,7 +990,7 @@ void delete_fn(file_info *finfo, const char *name, void *state)
 
     sprintf(FileName, "Thread_%05d.log", ProcessNumber);
 
-    if (finfo->mode & aDIR) 
+    if (finfo->mode & aDIR)
     {
         char s2[1024];
         sprintf(s2, "%s\\*", name);
@@ -980,7 +1004,7 @@ void delete_fn(file_info *finfo, const char *name, void *state)
         gle = GetLastError();
         if (!rc)
         {
-            LeaveThread(0, "", CMD_UNLINK);
+            LeaveThread(gle, "", CMD_UNLINK);
             sprintf(temp, "FILE: DeleteFile %s failed GLE(0x%x)\n", name, gle);
             if (verbose)
                 printf("%s", temp);
@@ -1019,7 +1043,7 @@ int nb_deltree(char *dname)
 
         if ((gle != ERROR_FILE_NOT_FOUND) && (gle != ERROR_PATH_NOT_FOUND))
         {
-            LeaveThread(0, "", CMD_DELTREE);
+            LeaveThread(gle, "", CMD_DELTREE);
             sprintf(FileName, "Thread_%05d.log", ProcessNumber);
             sprintf(temp, "ERROR: Thread %d - Unable to remove %s.\n", ProcessNumber, path);
             LogMessage(ProcessNumber, HostName, FileName, temp, LogID);
@@ -1207,7 +1231,7 @@ HANDLE CreateObject(const char *fname, uint32 DesiredAccess,
     {
         DWORD rc;
 
-        if (!CreateDirectory(fname, NULL) && (rc = GetLastError()) != ERROR_ALREADY_EXISTS) 
+        if (!CreateDirectory(fname, NULL) && (rc = GetLastError()) != ERROR_ALREADY_EXISTS)
         {
             SetLastError(rc);
             fd = INVALID_HANDLE_VALUE;
@@ -1358,14 +1382,14 @@ void SubstituteString(char *s,const char *pattern,const char *insert, size_t len
     li = (ssize_t)strlen(insert);
 
     if (!*pattern) return;
-	
+
     while (lp <= ls && (p = strstr(s,pattern)))
     {
-        if (len && (ls + (li-lp) >= (int)len)) 
+        if (len && (ls + (li-lp) >= (int)len))
         {
             break;
         }
-        if (li != lp) 
+        if (li != lp)
         {
             memmove(p+li,p+lp,strlen(p+lp)+1);
         }
@@ -1387,8 +1411,8 @@ B.tm_isdst = -1; \
 B.tm_mday = A.wDay;
 
 
-BOOL GetPathInfo(const char *fname, 
-		   time_t *c_time, time_t *a_time, time_t *m_time, 
+BOOL GetPathInfo(const char *fname,
+		   time_t *c_time, time_t *a_time, time_t *m_time,
 		   size_t *size, uint16 *mode)
 {
     WIN32_FILE_ATTRIBUTE_DATA FileInfo;
@@ -1417,7 +1441,7 @@ BOOL GetPathInfo(const char *fname,
             CHANGE_TIME(SystemTime, tm_time)
             (*m_time) = mktime(&tm_time);
         }
-        if (size) 
+        if (size)
         {
             rc = 1;
             if (!(FileInfo.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
@@ -1435,9 +1459,9 @@ BOOL GetPathInfo(const char *fname,
 /****************************************************************************
 send a qfileinfo call
 ****************************************************************************/
-BOOL GetFileInfo(char *FileName, HANDLE fd, 
+BOOL GetFileInfo(char *FileName, HANDLE fd,
                    uint16 *mode, size_t *size,
-                   time_t *c_time, time_t *a_time, time_t *m_time, 
+                   time_t *c_time, time_t *a_time, time_t *m_time,
                    time_t *w_time)
 {
     WIN32_FILE_ATTRIBUTE_DATA FileInfo;
@@ -1466,7 +1490,7 @@ BOOL GetFileInfo(char *FileName, HANDLE fd,
             CHANGE_TIME(SystemTime, tm_time)
             (*m_time) = mktime(&tm_time);
         }
-        if (size) 
+        if (size)
         {
             rc = 0;
             if (!(FileInfo.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
@@ -1491,7 +1515,7 @@ ssize_t nb_read(HANDLE fd, char *IoBuffer, off_t offset, size_t size)
     int     rc;
     DWORD   LowDword;
 
-    if (size == 0) 
+    if (size == 0)
         return(0);
 
     LowDword = SetFilePointer(fd, offset, 0, FILE_BEGIN);
