@@ -255,10 +255,9 @@ bc_ParseHosts(void)
 		    "can't get host info for %s from nameserver or /etc/hosts.",
 		    hostName);
 	}
-	the = (struct bc_hostEntry *)malloc(sizeof(struct bc_hostEntry));
+	the = calloc(1, sizeof(struct bc_hostEntry));
 	if (the == (struct bc_hostEntry *)0)
 	    return (BC_NOMEM);
-	memset(the, 0, sizeof(struct bc_hostEntry));
 	if (tlast) {
 	    tlast->next = the;
 	    tlast = the;
@@ -266,8 +265,7 @@ bc_ParseHosts(void)
 	    tfirst = tlast = the;
 	}
 	the->next = (struct bc_hostEntry *)0;
-	the->name = (char *)malloc(strlen(hostName) + 1);
-	strcpy(the->name, hostName);
+	the->name = strdup(hostName);
 	the->portOffset = port;
 	if (th) {
 	    memcpy(&the->addr.sin_addr.s_addr, th->h_addr, 4);
