@@ -13,14 +13,10 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-#ifndef AFS_NT40_ENV
-#include <netdb.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <afs/afsutil.h>
-#include <unistd.h>
-#endif
 
+#include <roken.h>
+
+#include <afs/afsutil.h>
 
 #include "vos.h"
 
@@ -139,18 +135,10 @@ GetAddressFromString(const char *addr_str)
     return ntohl(addr);
 }
 
-#if 0
-static void
-PrintMessage(vos_messageType_t type, char *message)
-{
-    printf("%s\n", message);
-}
-#endif
-
 int
 DoVosBackupVolumeCreate(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { VOLUME } DoVosBackupVolumeCreate_parm_t;
+    enum { VOLUME };
     afs_status_t st = 0;
     unsigned int volume_id = 0;
 
@@ -168,9 +156,9 @@ DoVosBackupVolumeCreate(struct cmd_syndesc *as, void *arock)
 int
 DoVosBackupVolumeCreateMultiple(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, PREFIX,
+    enum { SERVER, PARTITION, PREFIX,
 	EXCLUDE
-    } DoVosBackupVolumeCreate_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -220,7 +208,7 @@ Print_vos_partitionEntry_p(vos_partitionEntry_p part, const char *prefix)
 int
 DoVosPartitionGet(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION } DoVosPartitionGet_parm_t;
+    enum { SERVER, PARTITION };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -251,7 +239,7 @@ DoVosPartitionGet(struct cmd_syndesc *as, void *arock)
 int
 DoVosPartitionList(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER } DoVosPartitionGet_parm_t;
+    enum { SERVER };
     afs_status_t st = 0;
     void *vos_server = NULL;
     void *iter;
@@ -287,7 +275,7 @@ DoVosPartitionList(struct cmd_syndesc *as, void *arock)
 int
 DoVosServerSync(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION } DoVosServerSync_parm_t;
+    enum { SERVER, PARTITION };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -315,9 +303,9 @@ DoVosServerSync(struct cmd_syndesc *as, void *arock)
 int
 DoVosFileServerAddressChange(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { OLDADDRESS,
+    enum { OLDADDRESS,
 	NEWADDRESS
-    } DoVosFileServerAddressChange_parm_t;
+    };
     afs_status_t st = 0;
     int old_addr = 0;
     int new_addr = 0;
@@ -341,7 +329,7 @@ DoVosFileServerAddressChange(struct cmd_syndesc *as, void *arock)
 int
 DoVosFileServerAddressRemove(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { ADDRESS } DoVosFileServerAddressRemove_parm_t;
+    enum { ADDRESS };
     afs_status_t st = 0;
     int address = 0;
 
@@ -421,7 +409,7 @@ Print_vos_serverTransactionStatus_p(vos_serverTransactionStatus_p tran,
 int
 DoVosServerTransactionStatusList(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER } DoVosServerTransactionStatusList_parm_t;
+    enum { SERVER };
     afs_status_t st = 0;
     void *vos_server = NULL;
     void *iter = NULL;
@@ -529,7 +517,7 @@ Print_vos_vldbEntry_p(vos_vldbEntry_p entry, const char *prefix)
 int
 DoVosVLDBGet(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { VOLUME } DoVosVLDBGet_parm_t;
+    enum { VOLUME };
     afs_status_t st = 0;
     vos_vldbEntry_t entry;
     unsigned int volume_id;
@@ -553,7 +541,7 @@ DoVosVLDBGet(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBList(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION } DoVosVLDBList_parm_t;
+    enum { SERVER, PARTITION };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -601,7 +589,7 @@ DoVosVLDBList(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBEntryRemove(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME } DoVosVLDBEntryRemove_parm_t;
+    enum { SERVER, PARTITION, VOLUME };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -644,7 +632,7 @@ DoVosVLDBEntryRemove(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBUnlock(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION } DoVosVLDBUnlock_parm_t;
+    enum { SERVER, PARTITION };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -678,7 +666,7 @@ DoVosVLDBUnlock(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBEntryLock(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { VOLUME } DoVosVLDBEntryLoc_parm_tk;
+    enum { VOLUME };
     afs_status_t st = 0;
     unsigned int volume_id = 0;
 
@@ -697,7 +685,7 @@ DoVosVLDBEntryLock(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBEntryUnlock(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { VOLUME } DoVosVLDBEntryUnlock_parm_t;
+    enum { VOLUME };
     afs_status_t st = 0;
     unsigned int volume_id = 0;
 
@@ -716,9 +704,9 @@ DoVosVLDBEntryUnlock(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBReadOnlySiteCreate(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION,
+    enum { SERVER, PARTITION,
 	VOLUME
-    } DoVosVLDBReadOnlySiteCreate_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -751,9 +739,9 @@ DoVosVLDBReadOnlySiteCreate(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBReadOnlySiteDelete(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION,
+    enum { SERVER, PARTITION,
 	VOLUME
-    } DoVosVLDBReadOnlySiteDelete_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -787,7 +775,7 @@ DoVosVLDBReadOnlySiteDelete(struct cmd_syndesc *as, void *arock)
 int
 DoVosVLDBSync(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, FORCE } DoVosVLDBSync_parm_t;
+    enum { SERVER, PARTITION, FORCE };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -826,9 +814,9 @@ DoVosVLDBSync(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeCreate(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME,
+    enum { SERVER, PARTITION, VOLUME,
 	QUOTA
-    } DoVosVolumeCreate_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -871,7 +859,7 @@ DoVosVolumeCreate(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeDelete(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME } DoVosVolumeDelete_parm_t;
+    enum { SERVER, PARTITION, VOLUME };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -905,7 +893,7 @@ DoVosVolumeDelete(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeRename(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { OLDVOLUME, NEWVOLUME } DoVosVolumeRename_parm_t;
+    enum { OLDVOLUME, NEWVOLUME };
     afs_status_t st = 0;
     unsigned int old_volume = 0;
     char *new_volume = NULL;
@@ -929,9 +917,9 @@ DoVosVolumeRename(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeDump(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME, STARTTIME,
+    enum { SERVER, PARTITION, VOLUME, STARTTIME,
 	DUMPFILE
-    } DoVosVolumeDump_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id;
@@ -985,9 +973,9 @@ DoVosVolumeDump(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeRestore(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, ID, VOLUME, DUMPFILE,
+    enum { SERVER, PARTITION, ID, VOLUME, DUMPFILE,
 	FULL
-    } DoVosVolumeRestore_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1039,9 +1027,9 @@ DoVosVolumeRestore(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeOnline(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME, SLEEP,
+    enum { SERVER, PARTITION, VOLUME, SLEEP,
 	BUSY
-    } DoVosVolumeOnline_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1087,7 +1075,7 @@ DoVosVolumeOnline(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeOffline(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME } DoVosVolumeOffline_parm_t;
+    enum { SERVER, PARTITION, VOLUME };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1344,7 +1332,7 @@ Print_vos_volumeEntry_p(vos_volumeEntry_p entry, const char *prefix)
 int
 DoVosVolumeGet(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME } DoVosVolumeGet_parm_t;
+    enum { SERVER, PARTITION, VOLUME };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1381,7 +1369,7 @@ DoVosVolumeGet(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeList(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION } DoVosVolumeList_parm_t;
+    enum { SERVER, PARTITION };
     afs_status_t st = 0;
     void *vos_server = NULL;
     void *iter = NULL;
@@ -1427,9 +1415,9 @@ DoVosVolumeList(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeMove(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { VOLUME, FROMSERVER, FROMPARTITION, TOSERVER,
+    enum { VOLUME, FROMSERVER, FROMPARTITION, TOSERVER,
 	TOPARTITION
-    } DoVosVolumeMove_parm_t;
+    };
     afs_status_t st = 0;
     void *from_server = NULL;
     void *to_server = NULL;
@@ -1479,7 +1467,7 @@ DoVosVolumeMove(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeRelease(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { VOLUME, FORCE } DoVosVolumeRelease_parm_t;
+    enum { VOLUME, FORCE };
     afs_status_t st = 0;
     unsigned int volume_id = 0;
     vos_force_t force = VOS_NORMAL;
@@ -1502,7 +1490,7 @@ DoVosVolumeRelease(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeZap(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME, FORCE } DoVosVolumeZap_parm_t;
+    enum { SERVER, PARTITION, VOLUME, FORCE };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1541,7 +1529,7 @@ DoVosVolumeZap(struct cmd_syndesc *as, void *arock)
 int
 DoVosPartitionNameToId(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { PARTITION } DoVosPartitionNameToId_parm_t;
+    enum { PARTITION };
     unsigned int partition_id = 0;
 
     if (as->parms[PARTITION].items) {
@@ -1558,7 +1546,7 @@ DoVosPartitionNameToId(struct cmd_syndesc *as, void *arock)
 int
 DoVosPartitionIdToName(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { PARTITIONID } DoVosPartitionIdToName_parm_t;
+    enum { PARTITIONID };
     afs_status_t st = 0;
     unsigned int partition_id = 0;
     char partition[VOS_MAX_PARTITION_NAME_LEN];
@@ -1581,9 +1569,9 @@ DoVosPartitionIdToName(struct cmd_syndesc *as, void *arock)
 int
 DoVosVolumeQuotaChange(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME,
+    enum { SERVER, PARTITION, VOLUME,
 	QUOTA
-    } DoVosVolumeQuotaChange_parm_t;
+    };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1626,10 +1614,10 @@ DoVosVolumeQuotaChange(struct cmd_syndesc *as, void *arock)
 static afs_uint32
 GetServer(char *aname)
 {
-    register struct hostent *th;
+    struct hostent *th;
     afs_uint32 addr;
     int b1, b2, b3, b4;
-    register afs_int32 code;
+    afs_int32 code;
     char hostname[MAXHOSTCHARS];
 
     code = sscanf(aname, "%d.%d.%d.%d", &b1, &b2, &b3, &b4);
@@ -1643,7 +1631,7 @@ GetServer(char *aname)
 	memcpy(&addr, th->h_addr, sizeof(addr));
     }
 
-    if (addr == htonl(0x7f000001)) {	/* local host */
+    if (rx_IsLoopbackAddr(ntohl(addr))) {	/* local host */
 	code = gethostname(hostname, MAXHOSTCHARS);
 	if (code)
 	    return 0;
@@ -1743,7 +1731,7 @@ Print_vos_volintInfo(afs_uint32 server, afs_uint32 partition, volintInfo* pinfo,
 int
 DoVosVolumeGet2(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME } DoVosVolumeGet_parm_t;
+    enum { SERVER, PARTITION, VOLUME };
     afs_status_t st = 0;
     void *vos_server = NULL;
     afs_uint32 partition_id = 0;
@@ -1785,7 +1773,7 @@ DoVosVolumeGet2(struct cmd_syndesc *as, void *arock)
 int
 DoVos_ClearVolUpdateCounter(struct cmd_syndesc *as, void *arock)
 {
-    typedef enum { SERVER, PARTITION, VOLUME } DoVosVolumeGet_parm_t;
+    enum { SERVER, PARTITION, VOLUME };
     afs_status_t st = 0;
     void *vos_server = NULL;
     unsigned int partition_id = 0;
@@ -1821,13 +1809,13 @@ SetupVosAdminCmd(void)
 {
     struct cmd_syndesc *ts;
 
-    ts = cmd_CreateSyntax("VosBackupVolumeCreate", DoVosBackupVolumeCreate, NULL,
+    ts = cmd_CreateSyntax("VosBackupVolumeCreate", DoVosBackupVolumeCreate, NULL, 0,
 			  "create a backup volume");
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED, "volume to back up");
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("VosBackupVolumeCreateMultiple",
-			  DoVosBackupVolumeCreateMultiple, NULL,
+			  DoVosBackupVolumeCreateMultiple, NULL, 0,
 			  "create a backup volume");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_OPTIONAL,
 		"server housing volumes to back up");
@@ -1839,7 +1827,7 @@ SetupVosAdminCmd(void)
 		"exclude volumes from backup that match prefix");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosPartitionGet", DoVosPartitionGet, NULL,
+    ts = cmd_CreateSyntax("VosPartitionGet", DoVosPartitionGet, NULL, 0,
 			  "get information about a partition");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server housing partition of interest");
@@ -1847,13 +1835,13 @@ SetupVosAdminCmd(void)
 		"partition to query");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosPartitionList", DoVosPartitionList, NULL,
+    ts = cmd_CreateSyntax("VosPartitionList", DoVosPartitionList, NULL, 0,
 			  "list information about all partitions at a server");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server housing partitions of interest");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosServerSync", DoVosServerSync, NULL,
+    ts = cmd_CreateSyntax("VosServerSync", DoVosServerSync, NULL, 0,
 			  "sync server with vldb");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED, "server to sync");
     cmd_AddParm(ts, "-partition", CMD_SINGLE, CMD_OPTIONAL,
@@ -1861,7 +1849,7 @@ SetupVosAdminCmd(void)
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("VosFileServerAddressChange",
-			  DoVosFileServerAddressChange, NULL,
+			  DoVosFileServerAddressChange, NULL, 0,
 			  "change a server's address in the vldb");
     cmd_AddParm(ts, "-oldaddress", CMD_SINGLE, CMD_REQUIRED,
 		"old address to change");
@@ -1869,29 +1857,29 @@ SetupVosAdminCmd(void)
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("VosFileServerAddressRemove",
-			  DoVosFileServerAddressRemove, NULL,
+			  DoVosFileServerAddressRemove, NULL, 0,
 			  "remove a server's address from the vldb");
     cmd_AddParm(ts, "-address", CMD_SINGLE, CMD_REQUIRED,
 		"address to remove");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosFileServerList", DoVosFileServerList, NULL,
+    ts = cmd_CreateSyntax("VosFileServerList", DoVosFileServerList, NULL, 0,
 			  "list the file servers in a cell");
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("VosServerTransactionStatusList",
-			  DoVosServerTransactionStatusList, NULL,
+			  DoVosServerTransactionStatusList, NULL, 0,
 			  "list the active transactions at a server");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED, "server to query");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBGet", DoVosVLDBGet, NULL,
+    ts = cmd_CreateSyntax("VosVLDBGet", DoVosVLDBGet, NULL, 0,
 			  "get a vldb entry for a volume");
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED,
 		"volume to retrieve");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBList", DoVosVLDBList, NULL,
+    ts = cmd_CreateSyntax("VosVLDBList", DoVosVLDBList, NULL, 0,
 			  "list a group of vldb entries");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_OPTIONAL,
 		"limit entries to a particular server");
@@ -1899,7 +1887,7 @@ SetupVosAdminCmd(void)
 		"limit entries to a particular partition");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBEntryRemove", DoVosVLDBEntryRemove, NULL,
+    ts = cmd_CreateSyntax("VosVLDBEntryRemove", DoVosVLDBEntryRemove, NULL, 0,
 			  "remove vldb entries");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_OPTIONAL,
 		"limit entries to a particular server");
@@ -1908,7 +1896,7 @@ SetupVosAdminCmd(void)
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_OPTIONAL, "volume to remove");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBUnlock", DoVosVLDBUnlock, NULL,
+    ts = cmd_CreateSyntax("VosVLDBUnlock", DoVosVLDBUnlock, NULL, 0,
 			  "unlock a group of vldb entries");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_OPTIONAL,
 		"limit entries to a particular server");
@@ -1916,18 +1904,18 @@ SetupVosAdminCmd(void)
 		"limit entries to a particular partition");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBEntryLock", DoVosVLDBList, NULL,
+    ts = cmd_CreateSyntax("VosVLDBEntryLock", DoVosVLDBList, NULL, 0,
 			  "lock a single vldb entry");
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED, "volume to lock");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBEntryUnlock", DoVosVLDBEntryUnlock, NULL,
+    ts = cmd_CreateSyntax("VosVLDBEntryUnlock", DoVosVLDBEntryUnlock, NULL, 0,
 			  "unlock a single vldb entry");
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED, "volume to unlock");
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("VosVLDBReadOnlySiteCreate",
-			  DoVosVLDBReadOnlySiteCreate, NULL,
+			  DoVosVLDBReadOnlySiteCreate, NULL, 0,
 			  "create a read only site");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server where read only will be created");
@@ -1938,7 +1926,7 @@ SetupVosAdminCmd(void)
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("VosVLDBReadOnlySiteDelete",
-			  DoVosVLDBReadOnlySiteDelete, NULL,
+			  DoVosVLDBReadOnlySiteDelete, NULL, 0,
 			  "delete a read only site before initial replication");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_OPTIONAL,
 		"server where read only will be deleted");
@@ -1947,7 +1935,7 @@ SetupVosAdminCmd(void)
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED, "volume to delete");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVLDBSync", DoVosVLDBSync, NULL,
+    ts = cmd_CreateSyntax("VosVLDBSync", DoVosVLDBSync, NULL, 0,
 			  "sync vldb with server");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED, "server to sync");
     cmd_AddParm(ts, "-partition", CMD_SINGLE, CMD_OPTIONAL,
@@ -1955,7 +1943,7 @@ SetupVosAdminCmd(void)
     cmd_AddParm(ts, "-force", CMD_FLAG, CMD_OPTIONAL, "force sync to occur");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeCreate", DoVosVolumeCreate, NULL,
+    ts = cmd_CreateSyntax("VosVolumeCreate", DoVosVolumeCreate, NULL, 0,
 			  "create a read write volume");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server where volume will be created");
@@ -1967,7 +1955,7 @@ SetupVosAdminCmd(void)
 		"size quota of new volume in 1kb units");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeDelete", DoVosVolumeDelete, NULL,
+    ts = cmd_CreateSyntax("VosVolumeDelete", DoVosVolumeDelete, NULL, 0,
 			  "delete a volume");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server where volume exists");
@@ -1976,13 +1964,13 @@ SetupVosAdminCmd(void)
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED, "volume to delete");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeRename", DoVosVolumeRename, NULL,
+    ts = cmd_CreateSyntax("VosVolumeRename", DoVosVolumeRename, NULL, 0,
 			  "rename a volume");
     cmd_AddParm(ts, "-oldname", CMD_SINGLE, CMD_REQUIRED, "old volume name");
     cmd_AddParm(ts, "-newname", CMD_SINGLE, CMD_REQUIRED, "new volume name");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeDump", DoVosVolumeDump, NULL,
+    ts = cmd_CreateSyntax("VosVolumeDump", DoVosVolumeDump, NULL, 0,
 			  "dump a volume to a file");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_OPTIONAL,
 		"dump volume at a particular server");
@@ -1995,7 +1983,7 @@ SetupVosAdminCmd(void)
 		"file to contain dump results");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeRestore", DoVosVolumeRestore, NULL,
+    ts = cmd_CreateSyntax("VosVolumeRestore", DoVosVolumeRestore, NULL, 0,
 			  "restore a volume from a dumpfile");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses volume to restore");
@@ -2010,7 +1998,7 @@ SetupVosAdminCmd(void)
 		"does a full restore of volume");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeOnline", DoVosVolumeOnline, NULL,
+    ts = cmd_CreateSyntax("VosVolumeOnline", DoVosVolumeOnline, NULL, 0,
 			  "bring a volume online");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses volume");
@@ -2022,7 +2010,7 @@ SetupVosAdminCmd(void)
     cmd_AddParm(ts, "-busy", CMD_FLAG, CMD_OPTIONAL, "mark volume busy");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeOffline", DoVosVolumeOffline, NULL,
+    ts = cmd_CreateSyntax("VosVolumeOffline", DoVosVolumeOffline, NULL, 0,
 			  "take a volume offline");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses volume");
@@ -2032,7 +2020,7 @@ SetupVosAdminCmd(void)
 		"volume to bring offline");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeGet", DoVosVolumeGet, NULL,
+    ts = cmd_CreateSyntax("VosVolumeGet", DoVosVolumeGet, NULL, 0,
 			  "get a volume entry");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses volume");
@@ -2042,7 +2030,7 @@ SetupVosAdminCmd(void)
 		"volume to retrieve");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeList", DoVosVolumeList, NULL,
+    ts = cmd_CreateSyntax("VosVolumeList", DoVosVolumeList, NULL, 0,
 			  "list a group of volumes");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"limit volumes to a particular server");
@@ -2050,7 +2038,7 @@ SetupVosAdminCmd(void)
 		"limit volumes to a particular partition");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeMove", DoVosVolumeMove, NULL,
+    ts = cmd_CreateSyntax("VosVolumeMove", DoVosVolumeMove, NULL, 0,
 			  "move a volume");
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED, "volume to move");
     cmd_AddParm(ts, "-fromserver", CMD_SINGLE, CMD_REQUIRED, "source server");
@@ -2062,7 +2050,7 @@ SetupVosAdminCmd(void)
 		"destination partition");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeRelease", DoVosVolumeRelease, NULL,
+    ts = cmd_CreateSyntax("VosVolumeRelease", DoVosVolumeRelease, NULL, 0,
 			  "release updates to read only");
     cmd_AddParm(ts, "-volume", CMD_SINGLE, CMD_REQUIRED,
 		"volume to replicate");
@@ -2070,7 +2058,7 @@ SetupVosAdminCmd(void)
 		"force release to occur");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeZap", DoVosVolumeZap, NULL, "zap a volume");
+    ts = cmd_CreateSyntax("VosVolumeZap", DoVosVolumeZap, NULL, 0, "zap a volume");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses the volume to zap");
     cmd_AddParm(ts, "-partition", CMD_SINGLE, CMD_REQUIRED,
@@ -2079,18 +2067,18 @@ SetupVosAdminCmd(void)
     cmd_AddParm(ts, "-force", CMD_FLAG, CMD_OPTIONAL, "force zap");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosPartitionNameToId", DoVosPartitionNameToId, NULL,
+    ts = cmd_CreateSyntax("VosPartitionNameToId", DoVosPartitionNameToId, NULL, 0,
 			  "convert a partition name to a number");
     cmd_AddParm(ts, "-partition", CMD_SINGLE, CMD_REQUIRED,
 		"partition to convert");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosPartitionIdToName", DoVosPartitionIdToName, NULL,
+    ts = cmd_CreateSyntax("VosPartitionIdToName", DoVosPartitionIdToName, NULL, 0,
 			  "convert a number to a partition");
     cmd_AddParm(ts, "-id", CMD_SINGLE, CMD_REQUIRED, "number to convert");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeQuotaChange", DoVosVolumeQuotaChange, NULL,
+    ts = cmd_CreateSyntax("VosVolumeQuotaChange", DoVosVolumeQuotaChange, NULL, 0,
 			  "change the quota for a partition");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses the volume");
@@ -2101,7 +2089,7 @@ SetupVosAdminCmd(void)
 		"new quota in 1kb units");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("VosVolumeGet2", DoVosVolumeGet2, NULL,
+    ts = cmd_CreateSyntax("VosVolumeGet2", DoVosVolumeGet2, NULL, 0,
 			  "get a volume entry");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses volume");
@@ -2111,7 +2099,7 @@ SetupVosAdminCmd(void)
 		"volume to retrieve");
     SetupCommonCmdArgs(ts);
     
-    ts = cmd_CreateSyntax("ClearVolUpdateCounter", DoVos_ClearVolUpdateCounter, NULL,
+    ts = cmd_CreateSyntax("ClearVolUpdateCounter", DoVos_ClearVolUpdateCounter, NULL, 0,
 			  "clear volUpdateCounter");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED,
 		"server that houses volume");
