@@ -5,29 +5,32 @@
  * may copy or modify Sun RPC without charge, but are not authorized
  * to license or distribute it to anyone else except as part of a product or
  * program developed by the user.
- * 
+ *
  * SUN RPC IS PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND INCLUDING THE
  * WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS FOR A PARTICULAR
  * PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE OR TRADE PRACTICE.
- * 
+ *
  * Sun RPC is provided with no support and without any obligation on the
  * part of Sun Microsystems, Inc. to assist in its use, correction,
  * modification or enhancement.
- * 
+ *
  * SUN MICROSYSTEMS, INC. SHALL HAVE NO LIABILITY WITH RESPECT TO THE
  * INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY SUN RPC
  * OR ANY PART THEREOF.
- * 
+ *
  * In no event will Sun Microsystems, Inc. be liable for any lost revenue
  * or profits or other special, indirect and consequential damages, even if
  * Sun has been advised of the possibility of such damages.
- * 
+ *
  * Sun Microsystems, Inc.
  * 2550 Garcia Avenue
  * Mountain View, California  94043
  */
 #include <afsconfig.h>
 #include <afs/param.h>
+
+#include <roken.h>
+
 #include "rx.h"
 
 
@@ -43,8 +46,6 @@
  */
 
 #include "xdr.h"
-#include <stdio.h>
-#include <string.h>
 #define LASTUNSIGNED	((u_int)0-1)
 
 /*
@@ -57,7 +58,7 @@
  * proc is the routine to handle the referenced structure.
  */
 bool_t
-xdr_reference(XDR *xdrs, 
+xdr_reference(XDR *xdrs,
 	      caddr_t *pp, /* the pointer to work on */
 	      u_int size, /* size of the object pointed to */
 	      xdrproc_t proc)  /* xdr routine to handle the object */
