@@ -18,6 +18,8 @@
 #define SECURITY_WIN32
 #include <security.h>
 #include <nb30.h>
+#include <tchar.h>
+#include <strsafe.h>
 
 #include <osi.h>
 
@@ -38,7 +40,6 @@
 #include <WINNT/afsreg.h>
 #include <lanahelper.h>
 
-#include <loadfuncs-krb5.h>
 #include <krb5.h>
 #include <..\WINNT\afsrdr\common\AFSUserDefines.h>
 #include <..\WINNT\afsrdr\common\AFSUserIoctl.h>
@@ -171,7 +172,7 @@ RDR_Ready(void)
                                MAKELANGID(LANG_ENGLISH,SUBLANG_ENGLISH_US),
                                buf,
                                4096,
-                               (va_list *) NULL
+                               NULL
                                ) )
             {
                 fprintf(stderr,"RDR_Ready CreateFile(%S) failed: 0x%X\r\n\t[%s]\r\n",
@@ -185,12 +186,10 @@ RDR_Ready(void)
     //
     // Allocate a response buffer.
     //
-    respBuffer = (AFSDriverStatusRespCB *)malloc( sizeof( AFSDriverStatusRespCB));
+    respBuffer = calloc(1, sizeof( AFSDriverStatusRespCB));
     if( respBuffer)
     {
 
-	memset( respBuffer, '\0', sizeof( AFSDriverStatusRespCB));
-
         if( !DeviceIoControl( hDevHandle,
                               IOCTL_AFS_STATUS_REQUEST,
                               NULL,
@@ -216,7 +215,7 @@ RDR_Ready(void)
                                     MAKELANGID(LANG_ENGLISH,SUBLANG_ENGLISH_US),
                                     buf,
                                     4096,
-                                    (va_list *) NULL
+                                    NULL
                                     ) )
                 {
                     fprintf(stderr,"RDR_Ready CreateFile(%s) failed: 0x%X\r\n\t[%s]\r\n",
@@ -325,178 +324,138 @@ cleanup:
     return(hr);
 }
 
-// krb5 functions
-DECL_FUNC_PTR(krb5_cc_default_name);
-DECL_FUNC_PTR(krb5_cc_set_default_name);
-DECL_FUNC_PTR(krb5_get_default_config_files);
-DECL_FUNC_PTR(krb5_free_config_files);
-DECL_FUNC_PTR(krb5_free_context);
-DECL_FUNC_PTR(krb5_get_default_realm);
-DECL_FUNC_PTR(krb5_free_default_realm);
-DECL_FUNC_PTR(krb5_init_context);
-DECL_FUNC_PTR(krb5_cc_default);
-DECL_FUNC_PTR(krb5_parse_name);
-DECL_FUNC_PTR(krb5_free_principal);
-DECL_FUNC_PTR(krb5_cc_close);
-DECL_FUNC_PTR(krb5_cc_get_principal);
-DECL_FUNC_PTR(krb5_build_principal);
-DECL_FUNC_PTR(krb5_c_random_make_octets);
-DECL_FUNC_PTR(krb5_get_init_creds_password);
-DECL_FUNC_PTR(krb5_free_cred_contents);
-DECL_FUNC_PTR(krb5_cc_resolve);
-DECL_FUNC_PTR(krb5_unparse_name);
-DECL_FUNC_PTR(krb5_free_unparsed_name);
-
-FUNC_INFO krb5_fi[] = {
-    MAKE_FUNC_INFO(krb5_cc_default_name),
-    MAKE_FUNC_INFO(krb5_cc_set_default_name),
-    MAKE_FUNC_INFO(krb5_get_default_config_files),
-    MAKE_FUNC_INFO(krb5_free_config_files),
-    MAKE_FUNC_INFO(krb5_free_context),
-    MAKE_FUNC_INFO(krb5_get_default_realm),
-    MAKE_FUNC_INFO(krb5_free_default_realm),
-    MAKE_FUNC_INFO(krb5_init_context),
-    MAKE_FUNC_INFO(krb5_cc_default),
-    MAKE_FUNC_INFO(krb5_parse_name),
-    MAKE_FUNC_INFO(krb5_free_principal),
-    MAKE_FUNC_INFO(krb5_cc_close),
-    MAKE_FUNC_INFO(krb5_cc_get_principal),
-    MAKE_FUNC_INFO(krb5_build_principal),
-    MAKE_FUNC_INFO(krb5_c_random_make_octets),
-    MAKE_FUNC_INFO(krb5_get_init_creds_password),
-    MAKE_FUNC_INFO(krb5_free_cred_contents),
-    MAKE_FUNC_INFO(krb5_cc_resolve),
-    MAKE_FUNC_INFO(krb5_unparse_name),
-    MAKE_FUNC_INFO(krb5_free_unparsed_name),
-    END_FUNC_INFO
-};
-
-static int
-LoadFuncs(
-    const char* dll_name,
-    FUNC_INFO fi[],
-    HINSTANCE* ph,  // [out, optional] - DLL handle
-    int* pindex,    // [out, optional] - index of last func loaded (-1 if none)
-    int cleanup,    // cleanup function pointers and unload on error
-    int go_on,      // continue loading even if some functions cannot be loaded
-    int silent      // do not pop-up a system dialog if DLL cannot be loaded
-    )
-{
-    HINSTANCE h;
-    int i, n, last_i;
-    int error = 0;
-    UINT em;
-
-    if (ph) *ph = 0;
-    if (pindex) *pindex = -1;
-
-    for (n = 0; fi[n].func_ptr_var; n++)
-        *(fi[n].func_ptr_var) = 0;
-
-    if (silent)
-        em = SetErrorMode(SEM_FAILCRITICALERRORS);
-    h = LoadLibrary(dll_name);
-    if (silent)
-        SetErrorMode(em);
-
-    if (!h)
-        return 0;
-
-    last_i = -1;
-    for (i = 0; (go_on || !error) && (i < n); i++)
-    {
-        void* p = (void*)GetProcAddress(h, fi[i].func_name);
-        if (!p)
-            error = 1;
-        else
-        {
-            last_i = i;
-            *(fi[i].func_ptr_var) = p;
-        }
-    }
-    if (pindex) *pindex = last_i;
-    if (error && cleanup && !go_on) {
-        for (i = 0; i < n; i++) {
-            *(fi[i].func_ptr_var) = 0;
-        }
-        FreeLibrary(h);
-        return 0;
-    }
-    if (ph) *ph = h;
-    if (error) return 0;
-    return 1;
-}
-#if defined(_IA64_) || defined(_AMD64_)
-#define KERB5DLL "krb5_64.dll"
-#else
-#define KERB5DLL "krb5_32.dll"
-#endif
 static BOOL
-IsKrb5Available()
+UnicodeToANSI(LPCWSTR lpInputString, LPSTR lpszOutputString, int nOutStringLen)
 {
-    static HINSTANCE hKrb5DLL = 0;
+    CPINFO CodePageInfo;
 
-    if ( hKrb5DLL )
-        return TRUE;
+    GetCPInfo(CP_ACP, &CodePageInfo);
 
-    hKrb5DLL = LoadLibrary(KERB5DLL);
-    if (hKrb5DLL) {
-        if (!LoadFuncs(KERB5DLL, krb5_fi, 0, 0, 1, 0, 0))
+    if (CodePageInfo.MaxCharSize > 1) {
+        // Only supporting non-Unicode strings
+        int reqLen = WideCharToMultiByte( CP_ACP, 0,
+                                          lpInputString, -1,
+                                          NULL, 0, NULL, NULL);
+        if ( reqLen > nOutStringLen)
         {
-            FreeLibrary(hKrb5DLL);
-            hKrb5DLL = 0;
             return FALSE;
+        } else {
+            if (WideCharToMultiByte( CP_ACP,
+                                     WC_COMPOSITECHECK,
+                                     lpInputString, -1,
+                                     lpszOutputString,
+                                     nOutStringLen, NULL, NULL) == 0)
+                return FALSE;
         }
-        return TRUE;
     }
-    return FALSE;
+    else
+    {
+        // Looks like unicode, better translate it
+        if (WideCharToMultiByte( CP_ACP,
+                                 WC_COMPOSITECHECK,
+                                 lpInputString, -1,
+                                 lpszOutputString,
+                                 nOutStringLen, NULL, NULL) == 0)
+            return FALSE;
+    }
+
+    return TRUE;
 }
 
 static BOOL
-GetLSAPrincipalName(char * szUser, DWORD *dwSize)
+GetLSAPrincipalName(char * pszUser, DWORD dwUserSize)
 {
-    krb5_context   ctx = 0;
-    krb5_error_code code;
-    krb5_ccache mslsa_ccache=0;
-    krb5_principal princ = 0;
-    char * pname = 0;
-    BOOL success = 0;
+    KERB_QUERY_TKT_CACHE_REQUEST CacheRequest;
+    PKERB_RETRIEVE_TKT_RESPONSE pTicketResponse = NULL;
+    ULONG ResponseSize;
+    PKERB_EXTERNAL_NAME pClientName = NULL;
+    PUNICODE_STRING     pDomainName = NULL;
+    LSA_STRING Name;
+    HANDLE hLogon = INVALID_HANDLE_VALUE;
+    ULONG PackageId;
+    NTSTATUS ntStatus;
+    NTSTATUS ntSubStatus = 0;
+    WCHAR * wchUser = NULL;
+    DWORD   dwSize;
+    SHORT   sCount;
+    BOOL bRet = FALSE;
 
-    if (!IsKrb5Available())
-        return FALSE;
-
-    if (code = pkrb5_init_context(&ctx))
+    ntStatus = LsaConnectUntrusted( &hLogon);
+    if (FAILED(ntStatus))
         goto cleanup;
 
-    if (code = pkrb5_cc_resolve(ctx, "MSLSA:", &mslsa_ccache))
+    Name.Buffer = MICROSOFT_KERBEROS_NAME_A;
+    Name.Length = (USHORT)(sizeof(MICROSOFT_KERBEROS_NAME_A) - sizeof(char));
+    Name.MaximumLength = Name.Length;
+
+    ntStatus = LsaLookupAuthenticationPackage( hLogon, &Name, &PackageId);
+    if (FAILED(ntStatus))
         goto cleanup;
 
-    if (code = pkrb5_cc_get_principal(ctx, mslsa_ccache, &princ))
+    memset(&CacheRequest, 0, sizeof(KERB_QUERY_TKT_CACHE_REQUEST));
+    CacheRequest.MessageType = KerbRetrieveTicketMessage;
+    CacheRequest.LogonId.LowPart = 0;
+    CacheRequest.LogonId.HighPart = 0;
+
+    ntStatus = LsaCallAuthenticationPackage( hLogon,
+                                             PackageId,
+                                             &CacheRequest,
+                                             sizeof(CacheRequest),
+                                             &pTicketResponse,
+                                             &ResponseSize,
+                                             &ntSubStatus);
+    if (FAILED(ntStatus) || FAILED(ntSubStatus))
         goto cleanup;
 
-    if (code = pkrb5_unparse_name(ctx, princ, &pname))
-        goto cleanup;
+    /* We have a ticket in the response */
+    pClientName = pTicketResponse->Ticket.ClientName;
+    pDomainName = &pTicketResponse->Ticket.DomainName;
 
-    if ( strlen(pname) < *dwSize ) {
-        strncpy(szUser, pname, *dwSize);
-        szUser[*dwSize-1] = '\0';
-        success = 1;
+    /* We want to return ClientName @ DomainName */
+
+    dwSize = 0;
+    for ( sCount = 0; sCount < pClientName->NameCount; sCount++)
+    {
+        dwSize += pClientName->Names[sCount].Length;
     }
-    *dwSize = (DWORD)strlen(pname);
+    dwSize += pDomainName->Length + sizeof(WCHAR);
+
+    if ( dwSize / sizeof(WCHAR) > dwUserSize )
+        goto cleanup;
+
+    wchUser = malloc(dwSize);
+    if (wchUser == NULL)
+        goto cleanup;
+
+    for ( sCount = 0, wchUser[0] = L'\0'; sCount < pClientName->NameCount; sCount++)
+    {
+        StringCbCatNW( wchUser, dwSize,
+                       pClientName->Names[sCount].Buffer,
+                       pClientName->Names[sCount].Length);
+    }
+    StringCbCatNW( wchUser, dwSize,
+                   pDomainName->Buffer,
+                   pDomainName->Length);
+
+    if ( !UnicodeToANSI( wchUser, pszUser, dwUserSize) )
+        goto cleanup;
+
+    bRet = TRUE;
 
   cleanup:
-    if (pname)
-        pkrb5_free_unparsed_name(ctx, pname);
 
-    if (princ)
-        pkrb5_free_principal(ctx, princ);
+    if (wchUser)
+        free(wchUser);
 
-    if (mslsa_ccache)
-        pkrb5_cc_close(ctx, mslsa_ccache);
+    if ( hLogon != INVALID_HANDLE_VALUE)
+        LsaDeregisterLogonProcess(hLogon);
 
-    if (ctx)
-        pkrb5_free_context(ctx);
-    return success;
+    if ( pTicketResponse ) {
+        SecureZeroMemory(pTicketResponse,ResponseSize);
+        LsaFreeReturnBuffer(pTicketResponse);
+    }
+
+    return bRet;
 }
 
 //
@@ -887,7 +846,7 @@ GetIoctlHandle(char *fileNamep, HANDLE * handlep)
                                MAKELANGID(LANG_ENGLISH,SUBLANG_ENGLISH_US),
                                buf,
                                4096,
-                               (va_list *) NULL
+                               NULL
                                ) )
             {
                 fprintf(stderr,"pioctl GetFileAttributes(%s) failed: 0x%X\r\n\t[%s]\r\n",
@@ -962,7 +921,7 @@ GetIoctlHandle(char *fileNamep, HANDLE * handlep)
                                         MAKELANGID(LANG_ENGLISH,SUBLANG_ENGLISH_US),
                                         buf,
                                         4096,
-                                        (va_list *) NULL
+                                        NULL
                                         ) )
                     {
                         fprintf(stderr,"pioctl GetFileAttributes(%s) failed: 0x%X\r\n\t[%s]\r\n",
@@ -981,7 +940,7 @@ GetIoctlHandle(char *fileNamep, HANDLE * handlep)
         int  gonext = 0;
 
         dwSize = sizeof(szUser);
-        if (GetLSAPrincipalName(szUser, &dwSize)) {
+        if (GetLSAPrincipalName(szUser, dwSize)) {
             if ( ioctlDebug ) {
                 saveerrno = errno;
                 fprintf(stderr, "pioctl LSA Principal logon user: [%s]\r\n",szUser);
@@ -1031,7 +990,7 @@ GetIoctlHandle(char *fileNamep, HANDLE * handlep)
                                         MAKELANGID(LANG_ENGLISH,SUBLANG_ENGLISH_US),
                                         buf,
                                         4096,
-                                        (va_list *) NULL
+                                        NULL
                                         ) )
                     {
                         fprintf(stderr,"pioctl GetFileAttributes(%s) failed: 0x%X\r\n\t[%s]\r\n",
@@ -1094,7 +1053,7 @@ GetIoctlHandle(char *fileNamep, HANDLE * handlep)
                                         MAKELANGID(LANG_ENGLISH,SUBLANG_ENGLISH_US),
                                         buf,
                                         4096,
-                                        (va_list *) NULL
+                                        NULL
                                         ) )
                     {
                         fprintf(stderr,"pioctl GetFileAttributes(%s) failed: 0x%X\r\n\t[%s]\r\n",
