@@ -9,25 +9,16 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-#include <afs/afs_consts.h>
+#include <afs/opr.h>
 
-#include <errno.h>
-#include <sys/param.h>
-#include <sys/types.h>
+#include <roken.h>
+
+#include <afs/afs_consts.h>
 #include <afs/vice.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <netdb.h>
-#include <netinet/in.h>
-#include <sys/file.h>
-#endif
-#include <sys/stat.h>
-#include <stdio.h>
-#include <string.h>
 #include <afs/afsint.h>
 #include <afs/venus.h>
 #include <rx/xdr.h>
+
 #include "rmtsys.h"
 
 
@@ -91,7 +82,7 @@ RParseAcl(char *astr)
     last = 0;
     first = 0;
     for (i = 0; i < nplus; i++) {
-	sscanf(astr, "%100s %d", tname, &trights);
+	sscanf(astr, "%" opr_stringize(MAXNAME) "s %d", tname, &trights);
 	astr = RSkipLine(astr);
 	tl = calloc(sizeof(*tl), 1);
 	if (!first)
@@ -108,7 +99,7 @@ RParseAcl(char *astr)
     last = 0;
     first = 0;
     for (i = 0; i < nminus; i++) {
-	sscanf(astr, "%100s %d", tname, &trights);
+	sscanf(astr, "%" opr_stringize(MAXNAME) "s %d", tname, &trights);
 	astr = RSkipLine(astr);
 	tl = calloc(sizeof(*tl), 1);
 	if (!first)
