@@ -23,6 +23,7 @@
 #include <lock.h>
 #include <rx/rx.h>
 #include <afs/cellconfig.h>
+#include <afs/afsutil.h>
 
 
 #define UBIK_INTERNALS
@@ -78,7 +79,6 @@ afs_int32 ubik_quorum = 0;
 struct ubik_dbase *ubik_dbase = 0;
 struct ubik_stats ubik_stats;
 afs_uint32 ubik_host[UBIK_MAX_INTERFACE_ADDR];
-afs_int32 ubik_epochTime = 0;
 afs_int32 urecovery_state = 0;
 int (*ubik_SyncWriterCacheProc) (void);
 struct ubik_server *ubik_servers;
@@ -109,6 +109,7 @@ static void *securityRock = NULL;
 struct version_data version_globals;
 
 #define	CStampVersion	    1	/* meaning set ts->version */
+#define	CCheckSyncAdvertised	    2	/* check if the remote knows we are the sync-site */
 
 static_inline struct rx_connection *
 Quorum_StartIO(struct ubik_trans *atrans, struct ubik_server *as)
@@ -182,7 +183,10 @@ ContactQuorum_iterate(struct ubik_trans *atrans, int aflags, struct ubik_server
     if (!(*ts))
 	return 1;
     UBIK_BEACON_LOCK;
-    if (!(*ts)->up || !(*ts)->currentDB) {
+    if (!(*ts)->up || !(*ts)->currentDB ||
+	/* do not call DISK_Begin until we know that lastYesState is set on the
+	 * remote in question; otherwise, DISK_Begin will fail. */
+	((aflags & CCheckSyncAdvertised) && !((*ts)->beaconSinceDown && (*ts)->lastVote))) {
 	UBIK_BEACON_UNLOCK;
 	(*ts)->currentDB = 0;	/* db is no longer current; we just missed an update */
 	return 0;		/* not up-to-date, don't bother.  NULL conn will tell caller not to use */
@@ -202,7 +206,7 @@ ContactQuorum_rcode(int okcalls, afs_int32 rcode)
     if (okcalls + 1 >= ubik_quorum)
 	return 0;
     else
-	return rcode;
+	return (rcode != 0) ? rcode : UNOQUORUM;
 }
 
 /*!
@@ -219,7 +223,7 @@ ContactQuorum_rcode(int okcalls, afs_int32 rcode)
  * because it is sent the sync count along with the beacon message that
  * marks it as \b really up (\p beaconSinceDown).
  */
-afs_int32
+static afs_int32
 ContactQuorum_NoArguments(afs_int32 (*proc)(struct rx_connection *, ubik_tid *),
 	       		  struct ubik_trans *atrans, int aflags)
 {
@@ -238,7 +242,7 @@ ContactQuorum_NoArguments(afs_int32 (*proc)(struct rx_connection *, ubik_tid *),
 }
 
 
-afs_int32
+static afs_int32
 ContactQuorum_DISK_Lock(struct ubik_trans *atrans, int aflags,afs_int32 file,
 			afs_int32 position, afs_int32 length, afs_int32 type)
 {
@@ -256,27 +260,7 @@ ContactQuorum_DISK_Lock(struct ubik_trans *atrans, int aflags,afs_int32 file,
     return ContactQuorum_rcode(okcalls, rcode);
 }
 
-
-afs_int32
-ContactQuorum_DISK_Write(struct ubik_trans *atrans, int aflags,
-			 afs_int32 file, afs_int32 position, bulkdata *data)
-{
-    struct ubik_server *ts = NULL;
-    afs_int32 code = 0, rcode, okcalls;
-    struct rx_connection *conn;
-    int done;
-
-    done = ContactQuorum_iterate(atrans, aflags, &ts, &conn, &rcode, &okcalls, code);
-    while (!done) {
-	if (conn)
-	    code = DISK_Write(conn, &atrans->tid, file, position, data);
-	done = ContactQuorum_iterate(atrans, aflags, &ts, &conn, &rcode, &okcalls, code);
-    }
-    return ContactQuorum_rcode(okcalls, rcode);
-}
-
-
-afs_int32
+static afs_int32
 ContactQuorum_DISK_Truncate(struct ubik_trans *atrans, int aflags,
 			    afs_int32 file, afs_int32 length)
 {
@@ -295,7 +279,7 @@ ContactQuorum_DISK_Truncate(struct ubik_trans *atrans, int aflags,
 }
 
 
-afs_int32
+static afs_int32
 ContactQuorum_DISK_WriteV(struct ubik_trans *atrans, int aflags,
 			  iovec_wrt * io_vector, iovec_buf *io_buffer)
 {
@@ -437,6 +421,7 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
     tdb->getlabel = uphys_getlabel;
     tdb->setlabel = uphys_setlabel;
     tdb->getnfiles = uphys_getnfiles;
+    tdb->buffered_append = uphys_buf_append;
     tdb->readers = 0;
     tdb->tidCounter = tdb->writeTidCounter = 0;
     *dbase = tdb;
@@ -496,7 +481,7 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
 	rx_NewService(0, VOTE_SERVICE_ID, "VOTE", ubik_sc, numClasses,
 		      VOTE_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
-	ubik_dprint("Could not create VOTE rx service!\n");
+	ViceLog(0, ("Could not create VOTE rx service!\n"));
 	return -1;
     }
     rx_SetMinProcs(tservice, 2);
@@ -506,7 +491,7 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
 	rx_NewService(0, DISK_SERVICE_ID, "DISK", ubik_sc, numClasses,
 		      DISK_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
-	ubik_dprint("Could not create DISK rx service!\n");
+	ViceLog(0, ("Could not create DISK rx service!\n"));
 	return -1;
     }
     rx_SetMinProcs(tservice, 2);
@@ -609,9 +594,9 @@ BeginTrans(struct ubik_dbase *dbase, afs_int32 transMode,
 	/* it's not safe to use ubik_BeginTransReadAnyWrite without a
 	 * cache-syncing function; fall back to ubik_BeginTransReadAny,
 	 * which is safe but slower */
-	ubik_print("ubik_BeginTransReadAnyWrite called, but "
+	ViceLog(0, ("ubik_BeginTransReadAnyWrite called, but "
 	           "ubik_SyncWriterCacheProc not set; pretending "
-	           "ubik_BeginTransReadAny was called instead\n");
+	           "ubik_BeginTransReadAny was called instead\n"));
 	readAny = 1;
     }
 
@@ -644,6 +629,11 @@ BeginTrans(struct ubik_dbase *dbase, afs_int32 transMode,
 	    DBRELE(dbase);
 	    return UNOTSYNC;
 	}
+	if (!ubeacon_SyncSiteAdvertised()) {
+	    /* i am the sync-site but the remotes are not aware yet */
+	    DBRELE(dbase);
+	    return UNOQUORUM;
+	}
     }
 
     /* create the transaction */
@@ -661,29 +651,31 @@ BeginTrans(struct ubik_dbase *dbase, afs_int32 transMode,
 	}
     }
     /* label trans and dbase with new tid */
-    tt->tid.epoch = ubik_epochTime;
+    tt->tid.epoch = version_globals.ubik_epochTime;
     /* bump by two, since tidCounter+1 means trans id'd by tidCounter has finished */
     tt->tid.counter = (dbase->tidCounter += 2);
 
     if (transMode == UBIK_WRITETRANS) {
 	/* for a write trans, we have to keep track of the write tid counter too */
 	dbase->writeTidCounter = tt->tid.counter;
+    }
 
+    UBIK_VERSION_UNLOCK;
+
+    if (transMode == UBIK_WRITETRANS) {
 	/* next try to start transaction on appropriate number of machines */
-	code = ContactQuorum_NoArguments(DISK_Begin, tt, 0);
+	code = ContactQuorum_NoArguments(DISK_Begin, tt, CCheckSyncAdvertised);
 	if (code) {
 	    /* we must abort the operation */
 	    udisk_abort(tt);
 	    ContactQuorum_NoArguments(DISK_Abort, tt, 0); /* force aborts to the others */
 	    udisk_end(tt);
-	    UBIK_VERSION_UNLOCK;
 	    DBRELE(dbase);
 	    return code;
 	}
     }
 
     *transPtr = tt;
-    UBIK_VERSION_UNLOCK;
     DBRELE(dbase);
     return 0;
 }
@@ -895,7 +887,7 @@ ubik_EndTrans(struct ubik_trans *transPtr)
 	 * to us, or timeout.  Put safety check in anyway */
 	if (now - realStart > 10 * BIGTIME) {
 	    ubik_stats.escapes++;
-	    ubik_print("ubik escaping from commit wait\n");
+	    ViceLog(0, ("ubik escaping from commit wait\n"));
 	    break;
 	}
 	for (ts = ubik_servers; ts; ts = ts->next) {
@@ -1382,12 +1374,12 @@ panic(char *format, ...)
     va_list ap;
 
     va_start(ap, format);
-    ubik_print("Ubik PANIC: ");
-    ubik_vprint(format, ap);
+    ViceLog(0, ("Ubik PANIC:\n"));
+    vViceLog(0, (format, ap));
     va_end(ap);
 
     abort();
-    ubik_print("BACK FROM ABORT\n");	/* shouldn't come back */
+    ViceLog(0, ("BACK FROM ABORT\n"));	/* shouldn't come back */
     exit(1);			/* never know, though  */
 }
 
